#ifndef ENUMS_H
#define ENUMS_H

enum seqTextData_1w {
//***************************************************************************
// Hugo 1 Windows
//***************************************************************************
	kDTnull = 0,
	kDTnocgen_1w = 1, kDTnockey_1w,    kDTnoccandle_1w, kDTrnooil_1w,    kDTrnoknife_1w,
	kDTsgen_1w,       kDTslock_1w,     kDTsunlocked_1w, kDTsunlock_1w,   kDTsopenpkin_1w,
	kDTslocked_1w,    kDTsopen_1w,     kDTsclosed_1w,   kDTsbroken_1w,   kDTsnoseeoil_1w,
	kDTsworn1_1w,     kDTsworn2_1w,    kDTsworn3_1w,    kDTsoiled_1w,    kDTsstuck_1w,
	kDTsnocut_1w,     kDTsrock_1w,     kDTokgen_1w,     kDTokblow_1w,    kDTsseeoil_1w,
	kDTsruboil_1w,    kDTsrollrug_1w,  kDTsoilbolt_1w,  kDTsopenbolt_1w, kDTsclosebolt_1w,
	kDTscut_1w,       kDTsuntie_1w,    kDTsrbreak_1w,   kDTsplug_1w,     kDTsomattack_1w,
	kDTsNobody_1w,    kDTsUnlocked_1w, kDTthero_1w,     kDTtdoor_1w,     kDTtward_1w,
	kDTteyes_1w,      kDTtbat_1w,      kDTtpkin_1w,     kDTtkey_1w,      kDTtcandle_1w,
	kDTtknife_1w,     kDTtwhistle_1w,  kDTtmask_1w,     kDTtbutler_1w,   kDTtchop_1w,
	kDTtfrank_1w,     kDTtdrac_1w,     kDTtlady_1w,     kDTthood_1w,     kDTtslime_1w,
	kDTtpeahd_1w,     kDTtoilcan_1w,   kDTttrap_1w,     kDTtbolt_1w,     kDTtdog_1w,
	kDTtboat_1w,      kDTtrope_1w,     kDTtgold_1w,     kDTtoldman_1w,   kDTtguard_1w,
	kDTtprof_1w,      kDTtigor_1w,     kDTtbung_1w,     kDTupkin_1w,     kDTukey_1w,
	kDTucandle_1w,    kDTumasked_1w,   kDTubung_1w,     kDTuchop_1w,     kDTuknife_1w,
	kDTuoil_1w,       kDTugold_1w
};

enum seqTextData_2w {
//***************************************************************************
// Hugo 2 Windows
//***************************************************************************
	kDTdull_2w = 1,    kDTnopurps_2w,    kDTempty_2w,     kDTnocgen_2w,     kDTnomatch_2w,
	kDTnogun_2w,       kDTsgen_2w,       kDTsclose_2w,    kDTsbroken_2w,    kDTsopen1_2w,
	kDTsnoserum_2w,    kDTsharry_2w,     kDTsnoread_2w,   kDTsempty_2w,     kDTokgen_2w,
	kDTsthrown_2w,     kDTscatnip_2w,    kDTseatnip_2w,   kDTspaper_2w,     kDTsnopaper_2w,
	kDTspencil_2w,     kDTsgetlet_2w,    kDTsread_2w,     kDTwontopen_2w,   kDTspdoor_2w,
	kDTsopendum_2w,    kDTsunlockdum_2w, kDTsDarkHole_2w, kDTsFindMatch_2w, kDTsFindClove_2w,
	kDTsWhichColor_2w, kDTsNobody_2w,    kDTsUnlocked_2w, kDTthero_2w,      kDTtpenny_2w,
	kDTtdoor_2w,       kDTtdoordum_2w,   kDTtmaid_2w,     kDTthallgo_2w,    kDTtdog_2w,
	kDTtoldman_2w,     kDTtbookcase_2w,  kDTtbook_2w,     kDTtbed_2w,       kDTtbird_2w,
	kDTtmatch1_2w,     kDTtmatch2_2w,    kDTtballoon_2w,  kDTtdumb_2w,      kDTtrope_2w,
	kDTtgarlic_2w,     kDTtbutton_2w,    kDTtslight_2w,   kDTtglight_2w,    kDTtcatnip_2w,
	kDTtbridge_2w,     kDTtbug_2w,       kDTtsnake_2w,    kDTttardis_2w,    kDTtgun0_2w,
	kDTtgun1_2w,       kDTtdynamite_2w,  kDTtwell_2w,     kDTtlamp_2w,      kDTtbanana_2w,
	kDTtgenie_2w,      kDTtharry_2w,     kDTthester_2w,   kDTtletter_2w,    kDTtdoctor_2w,
	kDTtcook_2w,       kDTtcop_2w,       kDTthorace_2w,   kDTtrobot0_2w,    kDTtrobot1_2w,
	kDTtbell_2w,       kDTtbdoor_2w,     kDTtpencil_2w,   kDTtmagnify_2w,   kDTtsafe_2w,
	kDTtscrew_2w,      kDTtwill_2w,      kDTtalbum_2w,    kDTtcat_2w,       kDTtbottle_2w,
	kDTtzapper_2w,     kDTumatches_2w,   kDTugarlic_2w,   kDTustick_2w,     kDTubottle_2w,
	kDTudynamite_2w,   kDTugun_2w,       kDTubanana_2w,   kDTulamp_2w,      kDTuscrew_2w,
	kDTubell_2w,       kDTucatnip_2w,    kDTupaper_2w,    kDTupencil_2w,    kDTumagnify_2w
};

enum seqTextData_3w {
//***************************************************************************
// Hugo 3 Windows
//***************************************************************************
// Use following standard strings where applicable
	kDTdull_3w = 1,  kDTsdull_3w,     kDTnocgen_3w,    kDTnogun_3w,   kDTnopins_3w,
	kDTnocex_3w,     kDTsgen_3w,      kDTsclose_3w,    kDTsbroken_3w, kDTsopen1_3w,
	kDTsnosee_3w,    kDTsmade_3w,     kDTsfull_3w,     kDTsfoundb_3w, kDTsfoundc_3w,
	kDTslit_3w,      kDTsunlit_3w,    kDTsnoswing_3w,  kDTokgen_3w,   kDTsread_3w,
	kDTsfindc_3w,    kDTokbell_3w,    kDTswingcave_3w, kDTswinger_3w, kDTswater_3w,
	kDTsstream_3w,   kDTspool_3w,     kDTsblowdoc_3w,  kDTuclay_3w,   kDTuflask_3w,
	kDTubouillon_3w, kDTucage_3w,     kDTucrystal_3w,  kDTucheese_3w, kDTughost_3w,
	kDTuelephant_3w, kDTuread_3w,     kDTucandle_3w,   kDTubell_3w,   kDTupipe_3w,
	kDTsNobody_3w,   kDTsUnlocked_3w, kDTthero_3w,     kDTtpenny_3w,  kDTtplie_3w,
	kDTtplane_3w,    kDTtwwater_3w,   kDTtswater_3w,   kDTtmwater_3w, kDTtvine_3w,
	kDTtrush_3w,     kDTtsteps_3w,    kDTtdoctor_3w,   kDTtclay_3w,   kDTtneedles_3w,
	kDTtflask1_3w,   kDTtflask2_3w,   kDTtflask3_3w,   kDTtnative_3w, kDTtnatgirl_3w,
	kDTtmouse_3w,    kDTtcage1_3w,    kDTtcage2_3w,    kDTtpipe_3w,   kDTtelephant_3w,
	kDTtbouillon_3w, kDTtcheese_3w,   kDTtspider_3w,   kDTtscroll_3w, kDTtrock_3w,
	kDTtcrystal_3w,  kDTtghost_3w,    kDTtbell_3w,     kDTtbook_3w,   kDTtcandle_3w
};

enum seqTextData_1d {
//***************************************************************************
// Hugo 1 Dos
//***************************************************************************
	kDTnocgen_1d = 1, kDTnockey_1d,  kDTnoccandle_1d, kDTrnooil_1d,  kDTrnoknife_1d,
	kDTsgen_1d,       kDTslock_1d,   kDTsunlock_1d,   kDTsopen_1d,   kDTsclose_1d,
	kDTsbroken_1d,    kDTsopen2_1d,  kDTsnosee_1d,    kDTsworn1_1d,  kDTsworn2_1d,
	kDTsworn3_1d,     kDTsoiled_1d,  kDTsstuck_1d,    kDTsnocut_1d,  kDTokgen_1d,
	kDTsseeoil_1d,    kDTsruboil_1d, kDTscut_1d,      kDTsuntie_1d,  kDTsrbreak_1d,
	kDTsomattack_1d,  kDTthero_1d,   kDTtdoor_1d,     kDTtward_1d,   kDTteyes_1d,
	kDTtbat_1d,       kDTtpkin_1d,   kDTtkey_1d,      kDTtcandle_1d, kDTtknife_1d,
	kDTtwhistle_1d,   kDTtmask_1d,   kDTtbutler_1d,   kDTtchop_1d,   kDTtoilcan_1d,
	kDTtdog_1d,       kDTtboat_1d,   kDTtrope_1d,     kDTtgold_1d,   kDTtoldman_1d,
	kDTtguard_1d,     kDTtprof_1d,   kDTtigor_1d,     kDTtbung_1d,   kDTsknock_1d,
	kDTsong0_1d,      kDTsong1_1d,   kDTsong2_1d,     kDTsong3_1d
};

enum seqTextData_2d {
//***************************************************************************
// Hugo 2 Dos
//***************************************************************************
	kDTdull_2d = 1,    kDTnopurps_2d,   kDTempty_2d,         kDTnocgen_2d,    kDTnomatch_2d,
	kDTnogun_2d,       kDTsgen_2d,      kDTsclose_2d,        kDTsbroken_2d,   kDTsopen1_2d,
	kDTsnosee_2d,      kDTsharry_2d,    kDTsnoread_2d,       kDTsdialed_2d,   kDTsempty_2d,
	kDTokgen_2d,       kDTsthrown_2d,   kDTscatnip_2d,       kDTsgetlet_2d,   kDTsread_2d,
	kDTwontopen_2d,    kDTspdoor_2d,    kDTdarkhole_2d,      kDTfindmatch_2d, kDTfindclove_2d,
	kDTthero_2d,       kDTtpenny_2d,    kDTtdoor_2d,         kDTtmaid_2d,     kDTtdog_2d,
	kDTtoldman_2d,     kDTtbookcase_2d, kDTtbook_2d,         kDTtbird_2d,     kDTtballoon_2d,
	kDTtdumb_2d,       kDTtrope_2d,     kDTtgarlic_2d,       kDTtgardner_2d,  kDTtbutton_2d,
	kDTtbug_2d,        kDTtsnake_2d,    kDTtdynamite_2d,     kDTtwell_2d,     kDTtlamp_2d,
	kDTtbanana_2d,     kDTtgenie_2d,    kDTtharry_2d,        kDTthester_2d,   kDTtletter_2d,
	kDTtdoctor_2d,     kDTtcook_2d,     kDTtcop_2d,          kDTthorace_2d,   kDTtdalek_2d,
	kDTtbell_2d,       kDTtgun_2d,      kDTtbdoor_2d,        kDTtmagnify_2d,  kDTtsafe_2d,
	kDTtscrew_2d,      kDTtwill_2d,     kDTtalbum_2d,        kDTtbottle_2d,   kDTtzapper_2d,
	kDTtnoknock_2d,    kDTtnounlock_2d, kDTtnopushbutton_2d, kDTsong0_2d,     kDTsong1_2d,
	kDTsong2_2d,       kDTsong2a_2d,    kDTsong3_2d,         kDTsong4_2d,     kDTsong5_2d,
	kDTsong6_2d,       kDTsong7_2d,     kDTsong8_2d
};

enum seqTextData_3d {
//***************************************************************************
// Hugo 3 Dos
//***************************************************************************
	kDTdull_3d = 1,  kDTnopurps_3d,   kDTempty_3d,   kDTsdull_3d,    kDTnocgen_3d,
	kDTnogun_3d,     kDTnopins_3d,    kDTnocex_3d,   kDTsgen_3d,     kDTsclose_3d,
	kDTsbroken_3d,   kDTsopen1_3d,    kDTsnosee_3d,  kDTsmade_3d,    kDTsfull_3d,
	kDTsfoundc_3d,   kDTslit_3d,      kDTsunlit_3d,  kDTokgen_3d,    kDTsthrown_3d,
	kDTwontopen_3d,  kDTsread_3d,     kDTsfindc_3d,  kDTokbell_3d,   kDTswingcave_3d,
	kDTsNobody_3d,   kDTsUnlocked_3d, kDTthero_3d,   kDTtpenny_3d,   kDTtplane_3d,
	kDTtvine_3d,     kDTtdoctor_3d,   kDTtclay_3d,   kDTtneedles_3d, kDTtnative_3d,
	kDTtnatgirl_3d,  kDTtflask_3d,    kDTtmouse_3d,  kDTtcage_3d,    kDTtpipe_3d,
	kDTtelephant_3d, kDTtbouillon_3d, kDTtcheese_3d, kDTtspider_3d,  kDTtscroll_3d,
	kDTtcrystal_3d,  kDTtghost_3d,    kDTtbell_3d,   kDTtbook_3d,    kDTtcandle_3d,
// Added by Strangerke to improve Mouse support
	kDTtplie_3d,
//
	kDTsong0_3d,     kDTsong1_3d,     kDTsong2_3d,   kDTsong3_3d,
	kDTsong3a_3d,    kDTsong4_3d,     kDTsong5_3d,   kDTsong6_3d,    kDTsong7_3d,
	kDTsong8_3d,     kDTsong9_3d,     kDTsong10_3d,  kDTsong11_3d,   kDTsong12_3d
};

enum seqNouns_1w {
//***************************************************************************
// Hugo 1 Windows
//***************************************************************************
	kNDummy   = 0,
	kNHero_1w,       kNTrap_1w,        kNWard_1w,       kNDoor_1w,     kNBat_1w,
	kNEyes_1w,       kNBatpic_1w,      kNPkin_1w,       kNCandle_1w,   kNRope_1w,
	kNCupb_1w,       kNKnife_1w,       kNWhistle_1w,    kNWdoorl_1w,   kNWdoorr_1w,
	kNMask_1w,       kNButler_1w,      kNChop_1w,       kNRedeyes_1w,  kNLips_1w,
	kNArm_1w,        kNHdlshero_1w,    kNMonkey_1w,     kNKey_1w,      kNShed_1w,
	kNDog_1w,        kNCarpet_1w,      kNBolt_1w,       kNHerodead_1w, kNOilcan_1w,
	kNMummy_1w,      kNMdoor,          kNGold_1w,       kNBoat_1w,     kNOldman_1w,
	kNWhero_1w,      kNGuard_1w,       kNProf_1w,       kNIgor_1w,     kNBung_1w,
	kNGdoor_1w,      kNSpachero_1w,    kNFuzyhero_1w,   kNSpark_1w,    kNFrank_1w,
	kNDracula_1w,    kNGwen_1w,        kNHood_1w,       kNSlime_1w,    kNPeahead_1w,
	// Background objects:
	kNSky_1w,        kNWall_1w,        kNGround_1w,     kNTree_1w,     kNFence_1w,
	kNHouse_1w,      kNRoof_1w,        kNLight_1w,      kNMoon_1w,     kNPicture_1w,
	kNTable_1w,      kNStairs_1w,      kNBed_1w,        kNFace_1w,     kNPlant_1w,
	kNWitch_1w,      kNFood_1w,        kNWoman_1w,      kNMan_1w,      kNMirror_1w,
	kNToilet_1w,     kNBath_1w,        kNSink_1w,       kNUnits_1w,    kNBroom_1w,
	kNGardenbits_1w, kNMousehole_1w,   kNPenelope_1w,   kNRock_1w,     kNTomb_1w,
	kNBooth_1w,      kNDroppings_1w,   kNMachinebits_1w, kNMachine_1w,  kNHands_1w,
	kNWindow_1w,     kNCut_1w,         kNOil_1w
};

enum seqNouns_2w {
//***************************************************************************
// Hugo 2 Windows
//***************************************************************************
	kNHero_2w = 1, kNPenny_2w,     kNPennylie_2w,   kNPenfall_2w,  kNSmoke_2w,
	kNLips_2w,     kNMaid_2w,      kNHallgo_2w,     kNBookcase_2w, kNBook_2w,
	kNKeyhole_2w,  kNPanel_2w,     kNMatches_2w,    kNCrate_2w,    kNDumb_2w,
	kNMurder_2w,   kNGardner_2w,   kNTrap_2w,       kNWard_2w,     kNDoor_2w,
	kNGate_2w,     kNRope_2w,      kNRed_2w,        kNYellow_2w,   kNGreen_2w,
	kNBlue_2w,     kNFly_2w,       kNLeaf_2w,       kNCupb_2w,     kNGarlic_2w,
	kNButton_2w,   kNShedlight_2w, kNGatelight_2w,  kNZapper_2w,   kNBug_2w,
	kNKnife_2w,    kNShed_2w,      kNOldman_2w,     kNSnake_2w,    kNStick_2w,
	kNDynamite_2w, kNKennel_2w,    kNDog_2w,        kNWell_2w,     kNBanana_2w,
	kNLamp_2w,     kNGenie_2w,     kNTardis_2w,     kNHarry_2w,    kNHester_2w,
	kNLetter_2w,   kNDoctor_2w,    kNRobot_2w,      kNCook_2w,     kNCookb_2w,
	kNCop_2w,      kNHorace_2w,    kNBell_2w,       kNCatnip_2w,   kNCat_2w,
	kNGun_2w,      kNPaper_2w,     kNPencil_2w,     kNKey_2w,      kNMagnify_2w,
	kNSafe_2w,     kNScrew_2w,     kNWill_2w,       kNAlbum_2w,    kNBottle_2w,
	kNBalloon_2w,
	// Background objects:
	kNSky_2w,       kNWall_2w,       kNGround_2w,   kNTree_2w,
	kNFence_2w,    kNHouse_2w,     kNRoof_2w,       kNLight_2w,    kNMoon_2w,
	kNPicture_2w,  kNTable_2w,     kNStairs_2w,     kNBed_2w,      kNPlant_2w,
	kNFood_2w,     kNWoman_2w,     kNMan_2w,        kNMirror_2w,   kNSink_2w,
	kNUnits_2w,    kNBroom_2w,     kNGardenbits_2w, kNRock_2w,     kNDroppings_2w,
	kNWindow_2w,   kNBird_2w,      kNCage_2w,       kNPhone_2w,    kNBlotpad_2w,
	kNDrawer_2w,   kNChair_2w,     kNTools_2w,      kNBridge_2w,   kNWater_2w,
	kNBucket_2w,   kNMouse_2w,     kNWand_2w,       kNHole_2w,     kNMousehole_2w,
	kNHandle_2w,   kNChute_2w,     kNOrgan_2w,      kNPost_2w,     kNGraf_2w,
	// Added by Strangerke to ease things
	kNSwitch_2w,   kNBlock_2w
};

enum seqNouns_3w {
//***************************************************************************
// Hugo 3 Windows
//***************************************************************************
	kNHero_3w   = 1, kNWhero_3w,    kNHero_old_3w,  kNPenny_3w,    kNPennylie_3w,
	kNLips_3w,       kNPlane_3w,    kNDoor_3w,      kNBlock_3w,    kNCdoor_3w,
	kNVine_3w,       kNSwinger_3w,  kNSteps_3w,     kNDoctor_3w,   kNClay_3w,
	kNDoorlock_3w,   kNNeedles_3w,  kNNative_3w,    kNNat1_3w,     kNNat2_3w,
	kNNat3_3w,       kNNatb_3w,     kNNatg_3w,      kNBottles_3w,  kNFlask_3w,
	kNPipe_3w,       kNElephant_3w, kNE_eyes_3w,    kNBouillon_3w, kNMoushole_3w,
	kNDoclie_3w,     kNCheese_3w,   kNCage_3w,      kNSpider_3w,   kNSnake_3w,
	kNFire_3w,       kNDocbits_3w,  kNFire_1_3w,    kNFire_2_3w,   kNFire_3_3w,
	kNScroll_3w,     kNCrystal_3w,  kNGhost_3w,     kNBell_3w,     kNBook_3w,
	kNCandle_3w,     kNRush_3w,
	// Background objects:
	kNSky_3w,       kNWall_3w,     kNGround_3w,
	kNFence_3w,      kNBridge_3w,   kNWater_3w,     kNPool_3w,     kNWaterfall_3w,
	kNMouse_3w,      kNWindow_3w,   kNShelfbits_3w, kNOrchid_3w,   kNPole_3w,
	kNHut_3w,        kNRock_3w,     kNAircraft_3w,  kNPlant1_3w,   kNPlant2_3w,
	kNPlant3_3w,     kNPlant4_3w,   kNPlant5_3w,    kNJungle_3w,   kNWeb_3w,
	kNO_eye_3w,      kNFire_4_3w,   kNMouth_3w,     kNFood_3w,     kNThem_3w
};

enum seqNouns_1d {
//***************************************************************************
// Hugo 1 Dos
//***************************************************************************
	kNHero_1d = 1,   kNTrap_1d,        kNWard_1d,     kNDoor_1d,       kNBat_1d,
	kNEyes_1d,       kNPkin_1d,        kNCandle_1d,   kNRope_1d,       kNCupb_1d,
	kNKnife_1d,      kNWhistle_1d,     kNWdoorl_1d,   kNWdoorr_1d,     kNMask_1d,
	kNButler_1d,     kNChop_1d,        kNRedeyes_1d,  kNLips_1d,       kNArm_1d,
	kNHdlshero_1d,   kNMonkey_1d,      kNKey_1d,      kNShed_1d,       kNDog_1d,
	kNCarpet_1d,     kNBolt_1d,        kNHerodead_1d, kNOilcan_1d,     kNMummy_1d,
	kNMdoor_1d,      kNGold_1d,        kNBoat_1d,     kNWhero_1d,      kNOldman_1d,
	kNGuard_1d,      kNProf_1d,        kNIgor_1d,     kNBung_1d,       kNGdoor_1d,
	kNSpachero_1d,   kNFuzyhero_1d,    kNArc_1d,
	// Background objects:
	kNSky_1d,        kNWall_1d,
	kNGround_1d,     kNTree_1d,        kNFence_1d,    kNHouse_1d,      kNRoof_1d,
	kNLight_1d,      kNMoon_1d,        kNPicture_1d,  kNTable_1d,      kNStairs_1d,
	kNBed_1d,        kNFace_1d,        kNPlant_1d,    kNWitch_1d,      kNFood_1d,
	kNWoman_1d,      kNMan_1d,         kNMirror_1d,   kNToilet_1d,     kNBath_1d,
	kNSink_1d,       kNUnits_1d,       kNBroom_1d,    kNGardenbits_1d, kNMousehole_1d,
	kNPenelope_1d,   kNRock_1d,        kNTomb_1d,     kNDroppings_1d,  kNMachinebits_1d,
	kNHands_1d,      kNWindow_1d,
	// Added by Strangerke for mouse support
	kNBatpic_1d
};

enum seqNouns_2d {
//***************************************************************************
// Hugo 2 Dos
//***************************************************************************
	kNHero_2d = 1,   kNPenny_2d,   kNPennylie_2d,  kNPenfall_2d,  kNSmoke_2d,
	kNLips_2d,       kNMaid_2d,    kNBookcase_2d,  kNBook_2d,     kNKeyhole_2d,
	kNPanel_2d,      kNMatches_2d, kNCrate_2d,     kNDumb_2d,     kNMurder_2d,
	kNTrap_2d,       kNWard_2d,    kNDoor_2d,      kNRope_2d,     kNCupb_2d,
	kNGarlic_2d,     kNGardner_2d, kNButton_2d,    kNRed_2d,      kNYellow_2d,
	kNGreen_2d,      kNBlue_2d,    kNFly_2d,       kNLeaf_2d,     kNShedlight_2d,
	kNGatelight_2d,  kNZapper_2d,  kNBug_2d,       kNKnife_2d,    kNShed_2d,
	kNOldman_2d,     kNSnake_2d,   kNStick_2d,     kNDynamite_2d, kNKennel_2d,
	kNDog_2d,        kNWell_2d,    kNBanana_2d,    kNLamp_2d,     kNGenie_2d,
	kNTardis_2d,     kNHarry_2d,   kNHester_2d,    kNLetter_2d,   kNDoctor_2d,
	kNDalek_2d,      kNCook_2d,    kNCookb_2d,     kNCop_2d,      kNHorace_2d,
	kNBell_2d,       kNCatnip_2d,  kNCat_2d,       kNGun_2d,      kNPaper_2d,
	kNPencil_2d,     kNKey_2d,     kNMagnify_2d,   kNSafe_2d,     kNScrew_2d,
	kNWill_2d,       kNAlbum_2d,   kNBottle_2d,    kNBalloon_2d,  kNSky_2d,
	kNWall_2d,       kNGround_2d,  kNTree_2d,      kNFence_2d,    kNHouse_2d,
	kNRoof_2d,       kNLight_2d,   kNMoon_2d,      kNPicture_2d,  kNTable_2d,
	kNStairs_2d,     kNBed_2d,     kNPlant_2d,     kNFood_2d,     kNWoman_2d,
	kNMan_2d,        kNMirror_2d,  kNSink_2d,      kNUnits_2d,    kNBroom_2d,
	kNGardenbits_2d, kNRock_2d,    kNDroppings_2d, kNWindow_2d,   kNBird_2d,
	kNCage_2d,       kNPhone_2d,   kNChair_2d,     kNTools_2d,    kNBridge_2d,
	kNWater_2d,      kNBucket_2d,  kNMouse_2d,     kNWand_2d,     kNHole_2d,
	kNHandle_2d,     kNChute_2d,   kNOrgan_2d,     kNPost_2d,     kNGraf_2d
};

enum seqNouns_3d {
//***************************************************************************
// Hugo 3 Dos
//***************************************************************************
	kNHero_3d = 1,  kNWhero_3d,    kNHero_old_3d, kNWheroold_3d, kNPenny_3d,
	kNPennylie_3d,  kNLips_3d,     kNPlane_3d,    kNDoor_3d,     kNCdoor_3d,
	kNBlock_3d,     kNVine_3d,     kNSwinger_3d,  kNDoctor_3d,   kNClay_3d,
	kNDoorlock_3d,  kNNeedles_3d,  kNNative_3d,   kNNat1_3d,     kNNat2_3d,
	kNNat3_3d,      kNNatb_3d,     kNNatg_3d,     kNBottles_3d,  kNFlask_3d,
	kNCage_3d,      kNPipe_3d,     kNElephant_3d, kNE_eyes_3d,   kNBouillon_3d,
	kNMoushole_3d,  kNDoclie_3d,   kNCheese_3d,   kNSpider_3d,   kNSnake_3d,
	kNFire_3d,      kNDocbits_3d,  kNFire_1_3d,   kNFire_2_3d,   kNFire_3_3d,
	kNFroth_3d,     kNScroll_3d,   kNCrystal_3d,  kNGhost_3d,    kNBell_3d,
	kNBook_3d,      kNCandle_3d,   kNSky_3d,      kNWall_3d,     kNGround_3d,
	kNFence_3d,     kNBridge_3d,   kNWater_3d,    kNMouse_3d,    kNWindow_3d,
	kNShelfbits_3d, kNJungle_3d,   kNOrchid_3d,   kNPole_3d,     kNHut_3d,
	kNRock_3d,      kNAircraft_3d, kNPlant1_3d,   kNPlant2_3d,   kNPlant3_3d,
	kNPlant4_3d,    kNPlant5_3d,   kNWeb_3d,      kNO_eye_3d,    kNFire_4_3d,
	kNMouth_3d,     kNFood_3d,     kNThem_3d
};

enum seqVerbs_1w {
//***************************************************************************
// Hugo 1 Windows
//***************************************************************************
	kVDummy     = 0,
	kVMakeUseOf_1w, kVMagic_1w,       kVOpen_1w,       kVClose_1w,    kVUnlock_1w,
	kVLock_1w,      kVPush_1w,        kVGive_1w,       kVRude_1w,     kVOff_1w,
	kVInto_1w,      kVOutof_1w,       kVCrap_1w,       kVRide_1w,     kVTake_1w,
	kVDrop_1w,      kVAttack_1w,      kVBreak_1w,      kVThrowit_1w,  kVWear_1w,
	kVRub_1w,       kVOil_1w,         kVMove_1w,       kVLift_1w,     kVDig_1w,
	kVUnder_1w,     kVLook_1w,        kVEat_1w,        kVBlow_1w,     kVUntie_1w,
	kVCut_1w,       kVTalk_1w,        kVPlug_1w,
	// Background verbs:
	kVShout_1w,    kVQuery_1w,
	kVJump_1w,      kVGo_1w,          kVEnter_1w,      kVClimb_1w,    kVSwitch_1w,
	kVListen_1w,    kVKnock_1w,       kVSmell_1w,      kVSit_1w,      kVKiss_1w,
	kVUnbolt_1w,    kVLakeverbs_1w,   kVHelp_1w,       kVDrink_1w,    kVSweep_1w,
	kVFeed_1w,      kVWash_1w,        kVStroke_1w,     kVHide_1w,     kVBolt_1w,
	kVHero
};

enum seqVerbs_2w {
//***************************************************************************
// Hugo 2 Windows
//***************************************************************************
	kVMakeUseOf_2w = 1, kVBlock_2w,   kVUse_2w,    kVPush_2w,    kVUnder_2w,
	kVSearch_2w,        kVLook_2w,    kVMagic_2w,  kVOpen_2w,    kVClose_2w,
	kVUnlock_2w,        kVLock_2w,    kVRide_2w,   kVRest_2w,    kVUndress_2w,
	kVGive_2w,          kVUnscrew_2w, kVRude_2w,   kVOff_2w,     kVInto_2w,
	kVOutof_2w,         kVTake_2w,    kVDrop_2w,   kVAttack_2w,  kVBreak_2w,
	kVThrowit_2w,       kVWear_2w,    kVRub_2w,    kVOil_2w,     kVMove_2w,
	kVLift_2w,          kVDig_2w,     kVEat_2w,    kVBlow_2w,    kVUntie_2w,
	kVCut_2w,           kVTalk_2w,    kVStrike_2w, kVHerring_2w, kVRing_2w,
	kVRead_2w,          kVDial_2w,    kVFire_2w,
	//* Background verbs:
	kVShout_2w,   kVQuery_2w,
	kVJump_2w,          kVGo_2w,      kVClimb_2w,  kVSwitch_2w,  kVListen_2w,
	kVKnock_2w,         kVSmell_2w,   kVSit_2w,    kVKiss_2w,    kVHelp_2w,
	kVDrink_2w,         kVSweep_2w,   kVFeed_2w,   kVWash_2w,    kVHello_2w,
	kVWind_2w,          kVTie_2w,     kVStroke_2w, kVPlay_2w,    kVWish_2w,
	kVScribble_2w
};

enum seqVerbs_3w {
//***************************************************************************
// Hugo 3 Windows
//***************************************************************************
	kVMakeUseOf_3w = 1, kVPush_3w,    kVUnder_3w,  kVSearch_3w,   kVBehind_3w,
	kVLook_3w,          kVMagic_3w,   kVOpen_3w,   kVClose_3w,    kVRide_3w,
	kVRest_3w,          kVUndress_3w, kVGive_3w,   kVUnscrew_3w,  kVRude_3w,
	kVNaughty_3w,       kVOff_3w,     kVInto_3w,   kVOutof_3w,    kVTake_3w,
	kVDrop_3w,          kVUnlock_3w,  kVLock_3w,   kVAttack_3w,   kVBreak_3w,
	kVThrowit_3w,       kVWear_3w,    kVRub_3w,    kVOil_3w,      kVMove_3w,
	kVLift_3w,          kVDig_3w,     kVEat_3w,    kVBlow_3w,     kVUntie_3w,
	kVCut_3w,           kVFill_3w,    kVEmpty_3w,  kVDrink_3w,    kVStrike_3w,
	kVHerring_3w,       kVRing_3w,    kVRead_3w,   kVDial_3w,     kVShoot_3w,
	kVRepair_3w,        kVFly_3w,     kVDouse_3w,  kVExorcise_3w, kVSwing_3w,
	kVCross_3w,         kVMake_3w,    kVStick_3w,  kVTalk_3w,
	// Background verbs:
	kVShout_3w,
	kVQuery_3w,         kVJump_3w,    kVGo_3w,     kVClimb_3w,    kVSwitch_3w,
	kVListen_3w,        kVKnock_3w,   kVSmell_3w,  kVSit_3w,      kVKiss_3w,
	kVHelp_3w,          kVSweep_3w,   kVFeed_3w,   kVWash_3w,     kVHello_3w,
	kVWind_3w,          kVTie_3w,     kVStroke_3w, kVPlay_3w,     kVWish_3w,
	kVPut_3w,           kVUse_3w,     kVSwim_3w,   kVShow_3w
};

enum seqVerbs_1d {
//***************************************************************************
// Hugo 1 DOS
//***************************************************************************
	kVMagic_1d = 1, kVOpen_1d,  kVClose_1d, kVUnlock_1d, kVLock_1d,
	kVPush_1d,      kVGive_1d,  kVRude_1d,  kVOff_1d,    kVInto_1d,
	kVOutof_1d,     kVCrap_1d,  kVRide_1d,  kVTake_1d,   kVDrop_1d,
	kVAttack_1d,    kVBreak_1d, kVThrow_1d, kVWear_1d,   kVRub_1d,
	kVOil_1d,       kVMove_1d,  kVLift_1d,  kVDig_1d,    kVUnder_1d,
	kVLook_1d,      kVEat_1d,   kVBlow_1d,  kVUntie_1d,  kVCut_1d,
	kVTalk_1d,      kVPlug_1d,
	// Background verbs:
	kVShout_1d, kVQuery_1d,  kVJump_1d,
	kVGo_1d,        kVEnter_1d, kVClimb_1d, kVSwitch_1d, kVListen_1d,
	kVKnock_1d,     kVSmell_1d, kVSit_1d,   kVKiss_1d,   kVUnbolt_1d,
	kVLakeverbs_1d, kVHelp_1d,  kVDrink_1d, kVSweep_1d,  kVFeed_1d,
	kVWash_1d
};

enum seqVerbs_2d {
//***************************************************************************
// Hugo 2 DOS
//***************************************************************************
	kVBlock_2d = 1, kVUse_2d,     kVPush_2d,    kVUnder_2d,  kVSearch_2d,
	kVLook_2d,      kVOpen_2d,    kVClose_2d,   kVUnlock_2d, kVLock_2d,
	kVRide_2d,      kVRest_2d,    kVOff_2d,     kVInto_2d,   kVOutof_2d,
	kVTake_2d,      kVDrop_2d,    kVAttack_2d,  kVBreak_2d,  kVThrow_2d,
	kVWear_2d,      kVRub_2d,     kVOil_2d,     kVMove_2d,   kVLift_2d,
	kVEat_2d,       kVBlow_2d,    kVUntie_2d,   kVCut_2d,    kVTalk_2d,
	kVGive_2d,      kVStrike_2d,  kVHerring_2d, kVRing_2d,   kVRead_2d,
	kVDial_2d,      kVFire_2d,    kVShout_2d,   kVQuery_2d,  kVJump_2d,
	kVGo_2d,        kVClimb_2d,   kVSwitch_2d,  kVListen_2d, kVKnock_2d,
	kVSmell_2d,     kVSit_2d,     kVKiss_2d,    kVHelp_2d,   kVMagic_2d,
	kVDig_2d,       kVDrink_2d,   kVSweep_2d,   kVFeed_2d,   kVWash_2d,
	kVHello_2d,     kVWind_2d,    kVTie_2d,     kVStroke_2d, kVUnscrew_2d,
	kVRude_2d,      kVUndress_2d, kVPlay_2d,    kVWish_2d
};

enum seqVerbs_3d {
//***************************************************************************
// Hugo 3 DOS
//***************************************************************************
	kVPush_3d = 1, kVUnder_3d,  kVSearch_3d,   kVBehind_3d, kVLook_3d,
	kVMagic_3d,    kVOpen_3d,   kVClose_3d,    kVRide_3d,   kVRest_3d,
	kVUndress_3d,  kVGive_3d,   kVUnscrew_3d,  kVRude_3d,   kVNaughty_3d,
	kVOff_3d,      kVInto_3d,   kVOutof_3d,    kVTake_3d,   kVDrop_3d,
	kVUnlock_3d,   kVLock_3d,   kVAttack_3d,   kVBreak_3d,  kVThrow_3d,
	kVWear_3d,     kVRub_3d,    kVOil_3d,      kVMove_3d,   kVLift_3d,
	kVDig_3d,      kVEat_3d,    kVBlow_3d,     kVUntie_3d,  kVCut_3d,
	kVFill_3d,     kVEmpty_3d,  kVDrink_3d,    kVStrike_3d, kVHerring_3d,
	kVRing_3d,     kVRead_3d,   kVDial_3d,     kVShoot_3d,  kVRepair_3d,
	kVFly_3d,      kVDouse_3d,  kVExorcise_3d, kVSwing_3d,  kVCross_3d,
	kVMake_3d,     kVStick_3d,  kVTalk_3d,
	// Background verbs:
	kVShout_3d,  kVQuery_3d,
	kVJump_3d,     kVGo_3d,     kVClimb_3d,    kVSwitch_3d, kVListen_3d,
	kVKnock_3d,    kVSmell_3d,  kVSit_3d,      kVKiss_3d,   kVHelp_3d,
	kVSweep_3d,    kVFeed_3d,   kVWash_3d,     kVHello_3d,  kVWind_3d,
	kVTie_3d,      kVStroke_3d, kVPlay_3d,     kVWish_3d,   kVPut_3d,
	kVUse_3d,      kVSwim_3d,   kVShow_3d
};


enum seqActList_1w {
//***************************************************************************
// Hugo 1 Windows
//***************************************************************************
	kALDummy    = 0,
	kALgoinside_1w,    kALopendoor1_1w,   kALclosedoor1_1w,  kALightning_1w,   kALblinkeyes1_1w,
	kALbat_1w,         kALpkin_1w,        kALscr1_1w,        kALridprof_1w,    kALopendoor2_1w,
	kALopendoor3_1w,   kALblinkeyes2_1w,  kALscr10_1w,       kALscr13_1w,      kALscr15_1w,
	kALcuptxt0_1w,     kALcuptxt1_1w,     kALcuptxt2_1w,     kALcuptxt3_1w,    kALlookcupb2_1w,
	kALlookcupb1_1w,   kALlookcupb_1w,    kALcupbpk_1w,      kALcupbdw_1w,     kALchasehall_1w,
	kALchasekit_1w,    kALdefbats_1w,     kALnought_1w,      kALcond9_1w,      kALcond5_1w,
	kALblowdw_1w,      kALputmask_1w,     kALscr115_1w,      kALopenwdoorm_1w, kALopenwdoors_1w,
	kALclosewdoors_1w, kALswapmask_1w,    kALdropmask_1w,    kALwearmask_1w,   kALremovemask_1w,
	kALusemask_1w,     kALscr21_1w,       kALbut_1w,         kALbutler_1w,     kALbutp_1w,
	kALbutyes_1w,      kALbutno_1w,       kALbutchopped_1w,  kALbutchop_1w,    kALbutroam_1w,
	kALeatchop_1w,     kALeatchop2_1w,    kALthrowchop_1w,   kALchopfail_1w,   kALchoppass_1w,
	kALrepredeye_1w,   kALreplips_1w,     kALreparm_1w,      kALtalkfrank_1w,  kALtalkdrac_1w,
	kALtalkgwen_1w,    kALtalkhood_1w,    kALtalkslime_1w,   kALtalkpeahd_1w,  kALscr31_1w,
	kALscr35_1w,       kALscr41_1w,       kALscr51_1w,       kALscr53_1w,      kALscr56_1w,
	kALscr57_1w,       kALscr65_1w,       kALopenyes_1w,     kALopenno_1w,     kALopendoor4_1w,
	kALclosedoor4_1w,  kALshedoil_1w,     kALscr75_1w,       kALdog_1w,        kALdead_1w,
	kALdoggy_1w,       kALgetchop_1w,     kALmovecarp_1w,    kALridmask_1w,    kALopenpass_1w,
	kALopenfail_1w,    kALopentrap_1w,    kALclosetrap_1w,   kALscr89_1w,      kALscr87_1w,
	kALhelpy_1w,       kALhelpn_1w,       kALhelpy2_1w,      kALhelp_1w,       kALscr910_1w,
	kALscr98_1w,       kALbatrep_1w,      kALbatattack_1w,   kALbatty_1w,      kALbats_1w,
	kALmum_1w,         kALmummy_1w,       kALrock_1w,        kALscr109_1w,     kALscr1011_1w,
	kALscr1110_1w,     kALscr1112_1w,     kALcutrope_1w,     kALherofar_1w,    kALembark_1w,
	kALnobung_1w,      kALgetinboat_1w,   kALplugbung_1w,    kALdeboat_1w,     kALnodeboat_1w,
	kALchkout_1w,      kALgetoutboat_1w,  kALgofar_1w,       kALcomenear_1w,   kALmoveboat_1w,
	kALmoving_1w,      kALchkmove_1w,     kALnotcut_1w,      kALpushboat_1w,   kALchkboat2_1w,
	kALuseboat_1w,     kALrepno1_1w,      kALrepno3_1w,      kALrepyes1_1w,    kALrepyes2_1w,
	kALrepyes3_1w,     kALrepyes4_1w,     kALrepyes5_1w,     kALrepyes6_1w,    kALrepyes7_1w,
	kALomask_1w,       kALomasked_1w,     kALoldman_1w,      kALscr1213_1w,    kALjailrep_1w,
	kALend_1w,         kALjail_1w,        kALgive_1w,        kALnogive_1w,     kALgold_1w,
	kALscr1211_1w,     kALgoodbye_1w,     kALok151_1w,       kALdmsg3_1w,      kALdmsg2_1w,
	kALdmsg1_1w,       kALchkd3_1w,       kALchkd2_1w,       kALchkd1_1w,      kALscr151_1w,
	kALprof_1w,        kALlab_1w,         kALbox0_1w,        kALbbox_1w,       kALbox_1w,
	kALweird_1w,       kALcycle_1w,       kALinorm_1w,       kALigor3_1w,      kALigor2_1w,
	kALigor1_1w,       kALigor0_1w,       kALgobox_1w,       kALichk3_1w,      kALichk2_1w,
	kALichk1_1w,       kALichk0_1w,       kALigor_1w
};

enum seqActList_2w {
//***************************************************************************
// Hugo 2 Windows
//***************************************************************************
	kAL11maze_2w = 1, kAL_eatgar_2w,      kALballoon_2w,      kALbanana_2w,      kALbang1_2w,
	kALbang2_2w,      kALbed1_2w,         kALbell1_2w,        kALbell2_2w,       kALbell_2w,
	kALbite_2w,       kALblah_2w,         kALboom_2w,         kALbottle_2w,      kALbridge_2w,
	kALbugattack_2w,  kALbugflit_2w,      kALbugrep1_2w,      kALbugrep2_2w,     kALbugs_2w,
	kALbugzapper_2w,  kALcallp_2w,        kALcantpush_2w,     kALcat1_2w,        kALcat2_2w,
	kALcat3_2w,       kALcat4_2w,         kALcat5_2w,         kALcat6_2w,        kALcatnip_2w,
	kALchasm_2w,      kALcheat_2w,        kALchkbell2_2w,     kALchkc09_2w,      kALchkcarry_2w,
	kALchkdoc_2w,     kALchkld3_2w,       kALchkld4_2w,       kALchkmat1_2w,     kALchkmat2_2w,
	kALchkpap1_2w,    kALchkpap2_2w,      kALchkroute_2w,     kALchkrr2_2w,      kALchksafe_2w,
	kALchkscrew_2w,   kALchkstate1_2w,    kALclick_2w,        kALclimax_2w,      kALclimbrope_2w,
	kALclimbup_2w,    kALclimbwell_2w,    kALclue09_2w,       kALcomb1_2w,       kALcomb2_2w,
	kALcook_2w,       kALcookp_2w,        kALcop_2w,          kALcure_2w,        kALdial_2w,
	kALdialed_2w,     kALdidnt_2w,        kALdoctor_2w,       kALdog1_2w,        kALdone_2w,
	kALdropdyn1_2w,   kALdropdyn2_2w,     kALdropdynamite_2w, kALdropmat_2w,     kALdumb_2w,
	kALdyn1_2w,       kALeatban_2w,       kALeatbanana_2w,    kALempty_2w,       kALexitmaze_2w,
	kALfaint_2w,      kALgard1_2w,        kALgarlic_2w,       kALgatelight_2w,   kALgatescls_2w,
	kALgatesopn_2w,   kALgenie_2w,        kALgetbook_2w,      kALgetdynamite_2w, kALgetgarlic_2w,
	kALgetmatch_2w,   kALgiveb2_2w,       kALgiveb3_2w,       kALgiveb4_2w,      kALgivebel_2w,
	kALglchk2_2w,     kALglightoff_2w,    kALglighton_2w,     kALglook1_2w,      kALglook2_2w,
	kALgoclosed_2w,   kALgoopen_2w,       kALgotwill_2w,      kALgun_2w,         kALharry_2w,
	kALhdrink_2w,     kALheroxy01_2w,     kALhfaint_2w,       kALhole_2w,        kALhprompt_2w,
	kALhrgreet_2w,    kALhtable_2w,       kALhugone_2w,       kALkaboom3_2w,     kALkaboom_2w,
	kALkeyhole1_2w,   kALkeyhole2_2w,     kALkeyhole_2w,      kALlamp_2w,        kALlightdynamite_2w,
	kALlignpen_2w,    kALlookbrg_2w,      kALlookgard_2w,     kALlookkennel_2w,  kALmaid_2w,
	kALmaidbk_2w,     kALmaidp_2w,        kALmaidx_2w,        kALmap0_2w,        kALmap1_2w,
	kALmatok_2w,      kALmissed_2w,       kALnasty_2w,        kALnobang2_2w,     kALnobang_2w,
	kALnobell_2w,     kALnocarry_2w,      kALnocure_2w,       kALnodrink_2w,     kALnogenie_2w,
	kALnopurps_2w,    kALnoreply_2w,      kALnotrap_2w,       kALomgag_2w,       kALopendoor1_2w,
	kALopendoor2_2w,  kALopendoor3_2w,    kALpanel_2w,        kALparty_2w,       kALpencil_2w,
	kALpengone_2w,    kALpenny1_2w,       kALphone_2w,        kALphonebox_2w,    kALphoto1_2w,
	kALphoto2_2w,     kALphoto3_2w,       kALphoto_2w,        kALpois1_2w,       kALpois2_2w,
	kALpois3_2w,      kALpois4_2w,        kALpushpaper_2w,    kALpushpencil_2w,  kALreadlet_2w,
	kALrephest_2w,    kALrepmsg1_2w,      kALrg_2w,           kALridgard_2w,     kALridgarl_2w,
	kALridkey_2w,     kALrobot_2w,        kALrr_2w,           kALrumbling_2w,    kALsafe1_2w,
	kALsafe_2w,       kALsafepr_2w,       kALschedbut_2w,     kALscr0201_2w,     kALscr02_2w,
	kALscr0301_2w,    kALscr0305_2w,      kALscr0306_2w,      kALscr03_2w,       kALscr04_2w,
	kALscr0503_2w,    kALscr0603_2w,      kALscr0607_2w,      kALscr0631_2w,     kALscr06_2w,
	kALscr0706_2w,    kALscr0708_2w,      kALscr0710_2w,      kALscr0807_2w,     kALscr0809_2w,
	kALscr0908_2w,    kALscr09_2w,        kALscr1007_2w,      kALscr10_2w,       kALscr1108_2w,
	kALscr1113_2w,    kALscr1314_2w,      kALscr1413_2w,      kALscr1415_2w,     kALscr14_2w,
	kALscr1514_2w,    kALscr1516_2w,      kALscr1517_2w,      kALscr15_2w,       kALscr1615_2w,
	kALscr1715_2w,    kALscr1718_2w,      kALscr1720_2w,      kALscr1817_2w,     kALscr1819c_2w,
	kALscr1819l_2w,   kALscr1819r_2w,     kALscr1918c_2w,     kALscr1918l_2w,    kALscr1918r_2w,
	kALscr2017_2w,    kALscr2223_2w,      kALscr2322_2w,      kALscr2324_2w,     kALscr2325_2w,
	kALscr2326_2w,    kALscr2423_2w,      kALscr2523_2w,      kALscr25_2w,       kALscr2623_2w,
	kALscr2627_2w,    kALscr2726_2w,      kALscr2827_2w,      kALscr2829_2w,     kALscr2928_2w,
	kALscr2930_2w,    kALscr2931_2w,      kALscr2934_2w,      kALscr2938_2w,     kALscr29_2w,
	kALscr3029_2w,    kALscr30_2w,        kALscr3106_2w,      kALscr3129_2w,     kALscr3132_2w,
	kALscr3231_2w,    kALscr33_2w,        kALscr3429_2w,      kALscr3438_2w,     kALscr34_2w,
	kALscr3534_2w,    kALscr35_2w,        kALscr3634_2w,      kALscr36_2w,       kALscr3718_2w,
	kALscr3829_2w,    kALscr3834_2w,      kALscrgate1_2w,     kALscrgate2_2w,    kALscrok_2w,
	kALshedlight_2w,  kALshot_2w,         kALsilly_2w,        kALslightoff_2w,   kALslighton_2w,
	kALsnake_2w,      kALsoggy_2w,        kALsong3_2w,        kALsong4_2w,       kALsonic_2w,
	kALstopr_2w,      kALstrike_2w,       kALstrikematch_2w,  kALstuck_2w,       kALswgates_2w,
	kALswzapper_2w,   kALtakepaper_2w,    kALtalkgard_2w,     kALthrown_2w,      kALthrowstick_2w,
	kALtrap_2w,       kALuptrap_2w,       kALvenus_2w,        kALwho_2w,         kALwill1_2w,
	kALwill2_2w,      kALwill_2w,         kALworkgates_2w,    kALzapperoff_2w,   kALzapperon_2w,
	kALnewscr_2w,     kALscr01Story_2w,   kALscr01NoStory_2w

};

enum seqActList_3w {
//***************************************************************************
// Hugo 3 Windows
//***************************************************************************
	kALac2_3w = 1,        kALac3_3w,            kALac4_3w,            kALac5_3w,          kALac6_3w,
	kALac7_3w,            kALac8_3w,            kALac9_3w,            kALasleep_3w,       kALbittest_3w,
	kALblk1_3w,           kALblk_3w,            kALbrg_clftop1_3w,    kALbrg_clftop_3w,   kALbrg_clftop_msg_3w,
	kALbrg_down_3w,       kALbrg_ok_3w,         kALbrg_path_3w,       kALbridge_3w,       kALbridgetest_3w,
	kALbridgetip_3w,      kALbtip_3w,           kALbtipprompt_3w,     kALcageprompt_3w,   kALcagetest2_3w,
	kALcagetest3_3w,      kALcagetest4_3w,      kALcagetest_3w,       kALcamp_3w,         kALcamp_hut_3w,
	kALcamp_village_c_3w, kALcamp_village_l_3w, kALcampers_3w,        kALcanttake_3w,     kALcave_man_3w,
	kALcave_oldman_3w,    kALcave_turn_3w,      kALcave_wfall_3w,     kALchase_3w,        kALclf_clftop_3w,
	kALclf_wfall_3w,      kALclftop_brg_3w,     kALclftop_clf_3w,     kALclftop_slope_3w, kALclosedoor_3w,
	kALcom0_3w,           kALcom1_3w,           kALcom2_3w,           kALcom3_3w,         kALcom4_3w,
	kALcom5_3w,           kALcom6_3w,           kALcom7_3w,           kALcom8_3w,         kALcomment_3w,
	kALcrash_web_3w,      kALcrashed_3w,        kALcrashtest2_3w,     kALcryhelp_3w,      kALcrystal_3w,
	kALcubestip_3w,       kALdammed_3w,         kALdammedtip_3w,      kALdart_3w,         kALdarted_3w,
	kALdartedtest_3w,     kALdartsched_3w,      kALdn_3w,             kALdoc_3w,          kALdocgot_3w,
	kALdodart_3w,         kALdrink_3w,          kALdrinkno_3w,        kALdrinkyes_3w,     kALdropcheese_3w,
	kALdropincage_3w,     kALdropord_3w,        kALdroptest2_3w,      kALeatcheese_3w,    kALeatit_3w,
	kALele_sleep_3w,      kALeleblink_3w,       kALeletest2_3w,       kALempty2_3w,       kALemptymagic_3w,
	kALemptyord_3w,       kALemptytest2_3w,     kALentertest2_3w,     kALentertest3_3w,   kALexit_3w,
	kALexor_3w,           kALexorcise_3w,       kALexordone_3w,       kALexotest2_3w,     kALfill_3w,
	kALfillmagic_3w,      kALfillord_3w,        kALfilltest2_3w,      kALfilltest3_3w,    kALfindbook_3w,
	kALfindcrystal_3w,    kALfindit_3w,         kALflash_3w,          kALflask_3w,        kALflasktest2_3w,
	kALflasktest3_3w,     kALgarden_wbase_3w,   kALgettest2_3w,       kALgive_3w,         kALgiveb_3w,
	kALgivetest_3w,       kALgot_3w,            kALholel_3w,          kALholer_3w,        kALhorizdn_3w,
	kALhorizon_3w,        kALhorizup_3w,        kALhut_camp_3w,       kALhut_enter_3w,    kALhut_in_3w,
	kALhut_out_3w,        kALhut_village_c_3w,  kALhut_village_r_3w,  kALleft_3w,         kALlookfall_3w,
	kALlooknofall_3w,     kALlookwfall_3w,      kALmagictip_3w,       kALmakeclay_3w,     kALmakeit_3w,
	kALmission_3w,        kALmodeltip_3w,       kALmouse_3w,          kALmousego_3w,      kALmousegone_3w,
	kALmousel_3w,         kALmouser_3w,         kALmousetip_3w,       kALnat1_3w,         kALnat2_3w,
	kALnat3_3w,           kALnat4_3w,           kALnat5_3w,           kALnat6_3w,         kALnat7_3w,
	kALnat8_3w,           kALnat9_3w,           kALnative_3w,         kALnoblow_3w,       kALnoclay_3w,
	kALnofill_3w,         kALnomake_3w,         kALnoremedy_3w,       kALnospell_3w,      kALnostick_3w,
	kALnostickpin_3w,     kALnotakecb_3w,       kAL_nothanks_3w,      kALnotip_3w,        kALnottied_3w,
	kALoktoleave1_3w,     kALoktoleave2_3w,     kALold2_3w,           kALold3_3w,         kALold4_3w,
	kALold5_3w,           kALold6_3w,           kALold7_3w,           kALoldfirst_3w,     kALoldman_3w,
	kALoldmantip_3w,      kALoldsubseq_3w,      kALopencage_3w,       kALopencdoor_3w,    kALopendoor_3w,
	kALpath_3w,           kALpath_brg_3w,       kALpath_stream_3w,    kALpath_village_3w, kALpath_web_3w,
	kALplane_3w,          kALplanetip_3w,       kALpostest_3w,        kALprod_3w,         kALputitdown_3w,
	kALreadbook_3w,       kALreadord_3w,        kALreadtest2_3w,      kALrefuse_3w,       kALrefuseflask_3w,
	kALremedy_3w,         kALremedytip_3w,      kALreturn_3w,         kALright_3w,        kALscare_3w,
	kALscared_3w,         kALsleepy_3w,         kALslope_clftop_3w,   kALslope_stream_3w, kALspider_3w,
	kALspirit_3w,         kALsteps_3w,          kALstick_3w,          kALstickpin_3w,     kALsticktest1_3w,
	kALsticktest2_3w,     kALsticktest4_3w,     kALsticktip_3w,       kALstream1_3w,      kALstream2_3w,
	kALstream_path_3w,    kALstream_slope_3w,   kALstuckpin_3w,       kALsunset_3w,       kALswing_3w,
	kALswingtip_3w,       kALtakecage_3w,       kALtakecb_3w,         kALtakecheese_3w,   kALtakechs_3w,
	kALtakeit_3w,         kALtaketest1_3w,      kALtaketest2_3w,      kALtalkdoc1_3w,     kALtalkdoc2_3w,
	kALtalkdoc3_3w,       kALtalkdoc_3w,        kALtalknat_3w,        kALtalktest1_3w,    kALtalktest2_3w,
	kALtalkweb_3w,        kALtdtest_3w,         kALtied_3w,           kALtievine_3w,      kALtrapped_3w,
	kALturn_cave_3w,      kALturn_village_3w,   kALuntie_3w,          kALuntie_vine_3w,   kALup_3w,
	kALusecage_3w,        kALvillage_camp_l_3w, kALvillage_camp_r_3w, kALvillage_path_3w, kALvillage_thing_3w,
	kALvillage_turn_3w,   kALvine_3w,           kALwarn_3w,           kALwaterfall_3w,    kALwaternofall_3w,
	kALwbase_garden_3w,   kALwbase_wfall_3w,    kALweb_3w,            kALweb_crash_3w,    kALweb_path_3w,
	kALwebtest2_3w,       kALwfall_cave_3w,     kALwfall_clf_3w,      kALwfall_wbase_3w,  kALwfallb_cave_3w,
	kALwfallb_clf_3w,     kALwfallb_wbase_3w,   kALwrong_3w,          kALempty_3w,        kALgotit_3w,
	kALnocarry_3w,        kALnopurps_3w,        kALnothanks_3w,       kALok_3w,           kALstalk_3w,
	kALcrashStory_3w,     kALcrashNoStory_3w
};

enum seqActList_1d {
//***************************************************************************
// Hugo 1 Dos
//***************************************************************************
	kALbat_1d = 1,    kALbatattack_1d,  kALbatrep_1d,     kALbats_1d,       kALblinkeyes1_1d,
	kALblinkeyes2_1d, kALblowdw_1d,     kALbox0_1d,       kALbox_1d,        kALbut_1d,
	kALbutchop_1d,    kALbutchopped_1d, kALbutler_1d,     kALbutno_1d,      kALbutp_1d,
	kALbutroam_1d,    kALbutyes_1d,     kALchasehall_1d,  kALchasekit_1d,   kALchkd1_1d,
	kALchkd2_1d,      kALchkd3_1d,      kALchkmove_1d,    kALchkout_1d,     kALchopfail_1d,
	kALchoppass_1d,   kALclosedoor1_1d, kALclosedoor4_1d, kALclosetrap_1d,  kALclosewdoors_1d,
	kALcomenear_1d,   kALcond5_1d,      kALcond9_1d,      kALcupbdw_1d,     kALcupbpk_1d,
	kALcuptxt0_1d,    kALcuptxt1_1d,    kALcuptxt2_1d,    kALcuptxt3_1d,    kALcutrope_1d,
	kALcycle_1d,      kALdeboat_1d,     kALdefbats_1d,    kALdmsg1_1d,      kALdmsg2_1d,
	kALdmsg3_1d,      kALdog_1d,        kALdoggy_1d,      kALdropmask_1d,   kALeatchop_1d,
	kALembark_1d,     kALend_1d,        kALgetinboat_1d,  kALgetoutboat_1d, kALgive_1d ,
	kALgobox_1d,      kALgofar_1d,      kALgold_1d,       kALhelp_1d,       kALhelpn_1d,
	kALhelpy2_1d,     kALhelpy_1d,      kALherofar_1d,    kALichk0_1d,      kALichk1_1d,
	kALichk2_1d,      kALichk3_1d,      kALightning_1d,   kALigor0_1d,      kALigor1_1d,
	kALigor2_1d,      kALigor3_1d,      kALigor_1d,       kALinorm_1d,      kALjail_1d,
	kALjailrep_1d,    kALlab_1d,        kALlookcupb1_1d,  kALlookcupb2_1d,  kALlookcupb_1d,
	kALmoveboat_1d,   kALmovecarp_1d,   kALmoving_1d,     kALmum_1d,        kALmummy_1d,
	kALnodeboat_1d,   kALnogive_1d,     kALnotcut_1d,     kALnought_1d,     kALok151_1d,
	kALoldman_1d,     kALomask_1d,      kALomasked_1d,    kALopendoor1_1d,  kALopendoor2_1d,
	kALopendoor3_1d,  kALopendoor4_1d,  kALopenfail_1d,   kALopenno_1d,     kALopenpass_1d,
	kALopentrap_1d,   kALopenwdoors_1d, kALopenyes_1d,    kALpkin_1d,       kALplugbung_1d,
	kALprof_1d,       kALpushboat_1d,   kALputmask_1d,    kALreparm_1d,     kALreplips_1d,
	kALrepno1_1d,     kALrepno3_1d,     kALrepredeye_1d,  kALrepyes1_1d,    kALrepyes2_1d,
	kALrepyes3_1d,    kALrepyes4_1d,    kALrepyes5_1d,    kALrepyes6_1d,    kALrepyes7_1d,
	kALridmask_1d,    kALridprof_1d,    kALscr1011_1d,    kALscr109_1d,     kALscr10_1d,
	kALscr1110_1d,    kALscr1112_1d,    kALscr115_1d,     kALscr1211_1d,    kALscr1213_1d,
	kALscr13_1d,      kALscr151_1d,     kALscr15_1d,      kALscr1_1d,       kALscr21_1d,
	kALscr31_1d,      kALscr35_1d,      kALscr41_1d,      kALscr51_1d,      kALscr53_1d,
	kALscr56_1d,      kALscr57_1d,      kALscr65_1d,      kALscr75_1d,      kALscr87_1d,
	kALscr89_1d,      kALscr910_1d,     kALscr98_1d,      kALshedoil_1d,    kALsong1_1d,
	kALswapmask_1d,   kALthrowchop_1d,  kALweird_1d,      kALnobung_1d,     kALgoodbye_1d
};

enum seqActList_2d {
//***************************************************************************
// Hugo 2 Dos
//***************************************************************************
	kAL11maze_2d = 1, kALballoon_2d,       kALbanana_2d,     kALbang1_2d,     kALbang2_2d,
	kALbed1_2d,       kALbell_2d,          kALbell1_2d,      kALbell2_2d,     kALbite_2d,
	kALblah_2d,       kALboom_2d,          kALbottle_2d,     kALbridge_2d,    kALbugattack_2d,
	kALbugflit_2d,    kALbugrep1_2d,       kALbugrep2_2d,    kALbugs_2d,      kALbugzapper_2d,
	kALcallp_2d,      kALcantpush_2d,      kALcat1_2d,       kALcat2_2d,      kALcat3_2d,
	kALcat4_2d,       kALcat5_2d,          kALcat6_2d,       kALcatnip_2d,    kALchasm_2d,
	kALcheat_2d,      kALchkbell2_2d,      kALchkc09_2d,     kALchkcarry_2d,  kALchkdoc_2d,
	kALchkld3_2d,     kALchkld4_2d,        kALchkmat2_2d,    kALchkpap1_2d,   kALchkpap2_2d,
	kALchkrr2_2d,     kALchksafe_2d,       kALchkscrew_2d,   kALchkstate1_2d, kALclick_2d,
	kALclimax_2d,     kALclimbrope_2d,     kALclimbup_2d,    kALclimbwell_2d, kALclue09_2d,
	kALcomb1_2d,      kALcomb2_2d,         kALcook_2d,       kALcookp_2d,     kALcop_2d,
	kALcure_2d,       kALdalek_2d,         kALdial_2d,       kALdidnt_2d,     kALdoctor_2d,
	kALdog1_2d,       kALdone_2d,          kALdropdyn1_2d,   kALdropdyn2_2d,  kALdropdynamite_2d,
	kALdropmat_2d,    kALdumb_2d,          kALdyn1_2d,       kALeatbanana_2d, kALempty_2d,
	kALexitmaze_2d,   kALfaint_2d,         kALgard1_2d,      kALgarlic_2d,    kALgatelight_2d,
	kALgatescls_2d,   kALgatesopn_2d,      kALgenie_2d,      kALgetbook_2d,   kALgetdynamite_2d,
	kALgetgarlic_2d,  kALgetmatch_2d,      kALgiveb2_2d,     kALgiveb3_2d,    kALgiveb4_2d,
	kALgivebel_2d,    kALglightoff_2d,     kALglighton_2d,   kALgoclosed_2d,  kALgoopen_2d,
	kALgun_2d,        kALharry_2d,         kALhdrink_2d,     kALheroxy01_2d,  kALhfaint_2d,
	kALhole_2d,       kALhprompt_2d,       kALhrgreet_2d,    kALhtable_2d,    kALhugone_2d,
	kALkaboom_2d,     kALkaboom3_2d,       kALkeyhole_2d,    kALkeyhole1_2d,  kALkeyhole2_2d,
	kALlamp_2d,       kALlightdynamite_2d, kALlookkennel_2d, kALlookm1_2d,    kALlookm2_2d,
	kALlookmatch_2d,  kALmaid_2d,          kALmaidbk_2d,     kALmaidp_2d,     kALmaidx_2d,
	kALmap0_2d,       kALmap1_2d,          kALmatok_2d,      kALmissed_2d,    kALnasty_2d,
	kALnobang_2d,     kALnobang2_2d,       kALnobell_2d,     kALnocarry_2d,   kALnocure_2d,
	kALnodrink_2d,    kALnogenie_2d,       kALnopurps_2d,    kALnoreply_2d,   kALnotrap_2d,
	kALomgag_2d,      kALopendoor1_2d,     kALopendoor2_2d,  kALopendoor3_2d, kALpanel_2d,
	kALparty_2d,      kALpencil_2d,        kALpengone_2d,    kALpenny1_2d,    kALphone_2d,
	kALphonebox_2d,   kALphoto_2d,         kALphoto1_2d,     kALphoto2_2d,    kALphoto3_2d,
	kALpois1_2d,      kALpois2_2d,         kALpois3_2d,      kALpois4_2d,     kALpushpaper_2d,
	kALpushpencil_2d, kALreadlet_2d,       kALrepmsg1_2d,    kALrg_2d,        kALridgard_2d,
	kALridgarl_2d,    kALridkey_2d,        kALrr_2d,         kALrumbling_2d,  kALsafe_2d,
	kALsafe1_2d,      kALsafepr_2d,        kALschedbut_2d,   kALscr01_2d,     kALscr02_2d,
	kALscr0201_2d,    kALscr03_2d,         kALscr0301_2d,    kALscr0305_2d,   kALscr0306_2d,
	kALscr04_2d,      kALscr0503_2d,       kALscr06_2d,      kALscr0603_2d,   kALscr0607_2d,
	kALscr0631_2d,    kALscr0706_2d,       kALscr0708_2d,    kALscr0710_2d,   kALscr0807_2d,
	kALscr0809_2d,    kALscr09_2d,         kALscr0908_2d,    kALscr10_2d,     kALscr1007_2d,
	kALscr1108_2d,    kALscr1113_2d,       kALscr1314_2d,    kALscr14_2d,     kALscr1413_2d,
	kALscr1415_2d,    kALscr15_2d,         kALscr1514_2d,    kALscr1516_2d,   kALscr1517_2d,
	kALscr1615_2d,    kALscr1715_2d,       kALscr1718_2d,    kALscr1720_2d,   kALscr1817_2d,
	kALscr1819c_2d,   kALscr1819l_2d,      kALscr1819r_2d,   kALscr1918c_2d,  kALscr1918l_2d,
	kALscr1918r_2d,   kALscr2017_2d,       kALscr2223_2d,    kALscr2322_2d,   kALscr2324_2d,
	kALscr2325_2d,    kALscr2326_2d,       kALscr2423_2d,    kALscr2523_2d,   kALscr2623_2d,
	kALscr2627_2d,    kALscr2726_2d,       kALscr2827_2d,    kALscr2829_2d,   kALscr29_2d,
	kALscr2928_2d,    kALscr2930_2d,       kALscr2931_2d,    kALscr2934_2d,   kALscr2938_2d,
	kALscr30_2d,      kALscr3029_2d,       kALscr3106_2d,    kALscr3129_2d,   kALscr3132_2d,
	kALscr3231_2d,    kALscr33_2d,         kALscr34_2d,      kALscr3429_2d,   kALscr3438_2d,
	kALscr35_2d,      kALscr3534_2d,       kALscr36_2d,      kALscr3634_2d,   kALscr3718_2d,
	kALscr3829_2d,    kALscr3834_2d,       kALscrgate1_2d,   kALscrgate2_2d,  kALscrok_2d,
	kALshedlight_2d,  kALshot_2d,          kALsilly_2d,      kALslightoff_2d, kALslighton_2d,
	kALsnake_2d,      kALsong1_2d,         kALsong3_2d,      kALsong4_2d,     kALsonic_2d,
	kALstrike1_2d,    kALstrikematch_2d,   kALswgates_2d,    kALswzapper_2d,  kALthrown_2d,
	kALthrowstick_2d, kALtrap_2d,          kALuptrap_2d,     kALvenus_2d,     kALwho_2d,
	kALwill_2d,       kALwill1_2d,         kALwill2_2d,      kALworkgates_2d, kALzapperoff_2d,
	kALzapperon_2d,   kALnewscr_2d
};

enum seqActList_3d {
//***************************************************************************
// Hugo 3 Dos
//***************************************************************************
	kALac2_3d = 1,        kALac3_3d,            kALac4_3d,            kALac5_3d,            kALac6_3d,
	kALac7_3d,            kALac8_3d,            kALac9_3d,            kALasleep_3d,         kALbittest_3d,
	kALblk1_3d,           kALblk_3d,            kALbrg_clftop1_3d,    kALbrg_clftop_3d,     kALbrg_clftop_msg_3d,
	kALbrg_down_3d,       kALbrg_ok_3d,         kALbrg_path_3d,       kALbridgetip_3d,      kALbtip_3d,
	kALbtipprompt_3d,     kALcagetest2_3d,      kALcagetest3_3d,      kALcagetest4_3d,      kALcagetest_3d,
	kALcamp_3d,           kALcamp_hut_3d,       kALcamp_village_c_3d, kALcamp_village_l_3d, kALcampers_3d,
	kALcanttake_3d,       kALcave_man_3d,       kALcave_oldman_3d,    kALcave_turn_3d,      kALcave_wfall_3d,
	kALchase_3d,          kALclf_clftop_3d,     kALclf_wfall_3d,      kALclftop_brg_3d,     kALclftop_clf_3d,
	kALclftop_slope_3d,   kALclosedoor_3d,      kALcom0_3d,           kALcom1_3d,           kALcom2_3d,
	kALcom3_3d,           kALcom4_3d,           kALcom5_3d,           kALcom6_3d,           kALcom7_3d,
	kALcom8_3d,           kALcomment_3d,        kALcrashNoStory_3d,   kALcrashStory_3d,     kALcrash_web_3d,
	kALcrashed_3d,        kALcrashtest2_3d,     kALcryhelp_3d,        kALcrystal_3d,        kALcubestip_3d,
	kALdammed_3d,         kALdammedtip_3d,      kALdart_3d,           kALdarted_3d,         kALdartedtest_3d,
	kALdartsched_3d,      kALdn_3d,             kALdoc_3d,            kALdocgot_3d,         kALdodart_3d,
	kALdrink_3d,          kALdrinkno_3d,        kALdrinkyes_3d,       kALdropcheese_3d,     kALdropincage_3d,
	kALdropord_3d,        kALdroptest2_3d,      kALeatcheese_3d,      kALele_sleep_3d,      kALeleblink_3d,
	kALeletest2_3d,       kALempty_3d,          kALempty2_3d,         kALemptymagic_3d,     kALemptyord_3d,
	kALemptytest2_3d,     kALentertest2_3d,     kALentertest3_3d,     kALexit_3d,           kALexor_3d,
	kALexorcise_3d,       kALexordone_3d,       kALexotest2_3d,       kALfill_3d,           kALfillmagic_3d,
	kALfillord_3d,        kALfilltest2_3d,      kALfilltest3_3d,      kALfindbook_3d,       kALfindcrystal_3d,
	kALfindit_3d,         kALflash_3d,          kALflask_3d,          kALflasktest2_3d,     kALflasktest3_3d,
	kALgarden_wbase_3d,   kALgettest2_3d,       kALgive_3d,           kALgiveb_3d,          kALgivetest_3d,
	kALgot_3d,            kALgotit_3d,          kALholel_3d,          kALholer_3d,          kALhut_camp_3d,
	kALhut_enter_3d,      kALhut_in_3d,         kALhut_out_3d,        kALhut_village_c_3d,  kALhut_village_r_3d,
	kALleft_3d,           kALlookfall_3d,       kALlooknofall_3d,     kALlookwfall_3d,      kALmagictip_3d,
	kALmakeclay_3d,       kALmakeit_3d,         kALmap0_3d,           kALmap1_3d,           kALmission_3d,
	kALmodeltip_3d,       kALmouse_3d,          kALmousego_3d,        kALmousegone_3d,      kALmousel_3d,
	kALmouser_3d,         kALmousetip_3d,       kALnat1_3d,           kALnat2_3d,           kALnat3_3d,
	kALnat4_3d,           kALnat5_3d,           kALnat6_3d,           kALnat7_3d,           kALnat8_3d,
	kALnat9_3d,           kALnative_3d,         kALnoblow_3d,         kALnocarry_3d,        kALnoclay_3d,
	kALnofill_3d,         kALnomake_3d,         kALnopurps_3d,        kALnoremedy_3d,       kALnospell_3d,
	kALnostick_3d,        kALnostickpin_3d,     kALnotakecb_3d,       kALnothanks2_3d,      kALnothanks_3d,
	kALnotip_3d,          kALnottied_3d,        kALok_3d,             kALoktoleave1_3d,     kALoktoleave2_3d,
	kALold2_3d,           kALold3_3d,           kALold4_3d,           kALold5_3d,           kALold6_3d,
	kALold7_3d,           kALoldfirst_3d,       kALoldman_3d,         kALoldmantip_3d,      kALoldsubseq_3d,
	kALopencage_3d,       kALopencdoor_3d,      kALopendoor_3d,       kALpath_3d,           kALpath_brg_3d,
	kALpath_stream_3d,    kALpath_village_3d,   kALpath_web_3d,       kALplane_3d,          kALplanetip_3d,
	kALpostest_3d,        kALprod_3d,           kALputitdown_3d,      kALreadbook_3d,       kALreadord_3d,
	kALreadtest2_3d,      kALrefuse_3d,         kALrefuseflask_3d,    kALremedy_3d,         kALremedytip_3d,
	kALreturn_3d,         kALright_3d,          kALscare_3d,          kALscared_3d,         kALsleepy_3d,
	kALslope_clftop_3d,   kALslope_stream_3d,   kALsong3_3d,          kALspider_3d,         kALspirit_3d,
	kALstalk_3d,          kALstick_3d,          kALstickpin_3d,       kALsticktest1_3d,     kALsticktest2_3d,
	kALsticktest4_3d,     kALsticktip_3d,       kALstream1_3d,        kALstream2_3d,        kALstream_path_3d,
	kALstream_slope_3d,   kALstuckpin_3d,       kALsunset_3d,         kALswing_3d,          kALswingtip_3d,
	kALtakecage_3d,       kALtakecb_3d,         kALtakecheese_3d,     kALtakechs_3d,        kALtakeit_3d,
	kALtaketest1_3d,      kALtaketest2_3d,      kALtalknat_3d,        kALtalktest1_3d,      kALtalktest2_3d,
	kALtalkweb_3d,        kALtied_3d,           kALtievine_3d,        kALtrapped_3d,        kALturn_cave_3d,
	kALturn_village_3d,   kALuntie_3d,          kALuntie_vine_3d,     kALup_3d,             kALvillage_camp_l_3d,
	kALvillage_camp_r_3d, kALvillage_path_3d,   kALvillage_thing_3d,  kALvillage_turn_3d,   kALvine_3d,
	kALwarn_3d,           kALwaterfall_3d,      kALwaternofall_3d,    kALwbase_garden_3d,   kALwbase_wfall_3d,
	kALweb_3d,            kALweb_crash_3d,      kALweb_path_3d,       kALwebtest2_3d,       kALwfall_cave_3d,
	kALwfall_clf_3d,      kALwfall_wbase_3d,    kALwfallb_cave_3d,    kALwfallb_clf_3d,     kALwfallb_wbase_3d,
	kALwrong_3d,
// Added by Strangerke for Mouse support
	kALhorizdn_3d,        kALhorizon_3d,        kALhorizup_3d
};

// Enumerate picture files.  All screens must have an entry here, in order
enum screenid_1w {
	HOUSE_1w,   HALL_1w,    BED1_1w,     DININGRM_1w, BATHROOM_1w, KITCHEN_1w,
	GARDEN_1w,  STORERM_1w, BASEMENT_1w, BATCAVE_1w,  MUMMYRM_1w,  LAKEROOM_1w,
	DEADEND_1w, JAIL_1w,    THE_END_1w,  LAB_1w,      FINTRO_1w,   NUM_PICS_1w
};

enum screenid_2w {
	/* 0*/ HOUSE_2w,       HALL_2w,       BED1_2w,     BED2_2w,      KEYHOLE_FILE_2w,
	/* 5*/ BED3_2w,        KITCHEN_2w,    BACKDOOR_2w, SHED_2w,      INSHED_2w,
	/*10*/ VENUS_2w,       GATESOPN_2w,   GATESCLS_2w, STREAM_2w,    ZAPPER_FILE_2w,
	/*15*/ MUSHROOM_2w,    WELL_FILE_2w,  SNAKEPIT_2w, PHONEBOX_2w,  STREET_2w,
	/*20*/ KENNEL_FILE_2w, ROCKROOM_2w,   ROCKGONE_2w, THREEWAY_2w,  LAMPCAVE_2w,
	/*25*/ CHASM_2w,       PASSAGE_2w,    LADDER_2w,   TRAPROOM_2w,  HALL2_2w,
	/*30*/ LOUNGE_2w,      PARLOR_2w,     CATROOM_2w,  BOXROOM_2w,   HALL3_2w,
	/*35*/ ORGAN_2w,       HESTROOM_2w,   RETUPMOC_2w, HALL1_2w,

	// The maze madness: 8 x 8 array of screens
	// Remember to set MAZE_SCREEN to first maze screen number
	FMAZE01_2w,     FMAZE02_2w,    FMAZE03_2w,  FMAZE04_2w,   FMAZE05_2w,
	FMAZE06_2w,     FMAZE07_2w,    FMAZE08_2w,  FMAZE09_2w,   FMAZE10_2w,
	FMAZE11_2w,     FMAZE12_2w,    FMAZE13_2w,  FMAZE14_2w,   FMAZE15_2w,
	FMAZE16_2w,     FMAZE17_2w,    FMAZE18_2w,  FMAZE19_2w,   FMAZE20_2w,
	FMAZE21_2w,     FMAZE22_2w,    FMAZE23_2w,  FMAZE24_2w,   FMAZE25_2w,
	FMAZE26_2w,     FMAZE27_2w,    FMAZE28_2w,  FMAZE29_2w,   FMAZE30_2w,
	FMAZE31_2w,     FMAZE32_2w,    FMAZE33_2w,  FMAZE34_2w,   FMAZE35_2w,
	FMAZE36_2w,     FMAZE37_2w,    FMAZE38_2w,  FMAZE39_2w,   FMAZE40_2w,
	FMAZE41_2w,     FMAZE42_2w,    FMAZE43_2w,  FMAZE44_2w,   FMAZE45_2w,
	FMAZE46_2w,     FMAZE47_2w,    FMAZE48_2w,  FMAZE49_2w,   FMAZE50_2w,
	FMAZE51_2w,     FMAZE52_2w,    FMAZE53_2w,  FMAZE54_2w,   FMAZE55_2w,
	FMAZE56_2w,     FMAZE57_2w,    FMAZE58_2w,  FMAZE59_2w,   FMAZE60_2w,
	FMAZE61_2w,     FMAZE62_2w,    FMAZE63_2w,  FMAZE64_2w,
	FINTRO_2w,      NUM_PICS_2w
};

enum screenid_3w {
	CRASH_3w,   WEB_3w,      BRIDGE_3w,  BRIDGE2_3w, CLIFFTOP_3w,
	WFALL_3w,   WFALL_B_3w,  WBASE_3w,   STREAM_3w,  STREAM2_3w,
	PATH_UL_3w, VILLAGE_3w,  HUT_OUT_3w, HUT_IN_3w,  GARDEN_3w,
	OLDMAN_3w,  CLIFF_3w,    SLOPE_3w,   CAMP_3w,    SUNSET_3w,
	TURN_3w,    PLANE_3w,    MAP_3w,     PATH_3w,    CAVE_3w,
	FINTRO_3w,  NUM_PICS_3w
};

// Hugo 1 DOS doesn't use a DAT file : the screen files are not packed together
//enum screenid_1d {NUM_PICS_1d};
enum screenid_1d {
	HOUSE_1d,   HALL_1d,    BED1_1d,     DININGRM_1d, BATHROOM_1d, KITCHEN_1d,
	GARDEN_1d,  STORERM_1d, BASEMENT_1d, BATCAVE_1d,  MUMMYRM_1d,  LAKEROOM_1d,
	DEADEND_1d, JAIL_1d,    THE_END_1d,  LAB_1d,      FINTRO_1d,   NUM_PICS_1d
};


enum screenid_2d {
	/* 0*/ HOUSE_2d,       HALL_2d,      BED1_2d,     BED2_2d,     KEYHOLE_FILE_2d,
	/* 5*/ BED3_2d,        KITCHEN_2d,   BACKDOOR_2d, SHED_2d,     INSHED_2d,
	/*10*/ VENUS_2d,       GATESOPN_2d,  GATESCLS_2d, STREAM_2d,   ZAPPER_FILE_2d,
	/*15*/ MUSHROOM_2d,    WELL_FILE_2d, SNAKEPIT_2d, PHONEBOX_2d, STREET_2d,
	/*20*/ KENNEL_FILE_2d, ROCKROOM_2d,  ROCKGONE_2d, THREEWAY_2d, LAMPCAVE_2d,
	/*25*/ CHASM_2d,       PASSAGE_2d,   LADDER_2d,   TRAPROOM_2d, HALL2_2d,
	/*30*/ LOUNGE_2d,      PARLOR_2d,    CATROOM_2d,  BOXROOM_2d,  HALL3_2d,
	/*35*/ ORGAN_2d,       HESTROOM_2d,  RETUPMOC_2d, HALL1_2d,

// The maze madness: 8 x 8 array of screens
// Remember to set MAZE_SCREEN to first maze screen number
	FMAZE01_2d, FMAZE02_2d, FMAZE03_2d, FMAZE04_2d, FMAZE05_2d, FMAZE06_2d, FMAZE07_2d, FMAZE08_2d,
	FMAZE09_2d, FMAZE10_2d, FMAZE11_2d, FMAZE12_2d, FMAZE13_2d, FMAZE14_2d, FMAZE15_2d, FMAZE16_2d,
	FMAZE17_2d, FMAZE18_2d, FMAZE19_2d, FMAZE20_2d, FMAZE21_2d, FMAZE22_2d, FMAZE23_2d, FMAZE24_2d,
	FMAZE25_2d, FMAZE26_2d, FMAZE27_2d, FMAZE28_2d, FMAZE29_2d, FMAZE30_2d, FMAZE31_2d, FMAZE32_2d,
	FMAZE33_2d, FMAZE34_2d, FMAZE35_2d, FMAZE36_2d, FMAZE37_2d, FMAZE38_2d, FMAZE39_2d, FMAZE40_2d,
	FMAZE41_2d, FMAZE42_2d, FMAZE43_2d, FMAZE44_2d, FMAZE45_2d, FMAZE46_2d, FMAZE47_2d, FMAZE48_2d,
	FMAZE49_2d, FMAZE50_2d, FMAZE51_2d, FMAZE52_2d, FMAZE53_2d, FMAZE54_2d, FMAZE55_2d, FMAZE56_2d,
	FMAZE57_2d, FMAZE58_2d, FMAZE59_2d, FMAZE60_2d, FMAZE61_2d, FMAZE62_2d, FMAZE63_2d, FMAZE64_2d,
	FINTRO_2d,  LASTPIC_2d
};

enum screenid_3d {
	CRASH_3d,   WEB_3d,      BRIDGE_3d,  BRIDGE2_3d, CLIFFTOP_3d,
	WFALL_3d,   WFALL_B_3d,  WBASE_3d,   STREAM_3d,  STREAM2_3d,
	PATH_UL_3d, VILLAGE_3d,  HUT_OUT_3d, HUT_IN_3d,  GARDEN_3d,
	OLDMAN_3d,  CLIFF_3d,    SLOPE_3d,   CAMP_3d,    SUNSET_3d,
	TURN_3d,    PLANE_3d,    MAP_3d,     PATH_3d,    CAVE_3d,
	FINTRO_3d,  NUM_PICS_3d
};

enum string_t_1w {
//Hugo 1
	kSTsOk_1w,            kSTNopurps_1w,        kSTtrywalk_1w,         kSTnothing_1w,         kSTenopurps_1w,
	kSTnoidea_1w,         kSTedull_1w,          kSTeempty_1w,          kSTchop1_1w,           kSTnowayhose_1w,
	kSTnounder_1w,        kSTnojump_1w,         kSTnoclimb_1w,         kSTnotalk_1w,          kSTnoattack_1w,
	kSTnobreak_1w,        kSTnonoise_1w,        kSTnosmell_1w,         kSTnodig_1w,           kSTnorude_1w,
	kSTnoanswer_1w,       kSTlooksky_1w,        kSTaskhelp_1w,         kSTabracadabra_1w,     kSTlookscreen0_1w,
	kSTlooktree_1w,       kSTlookfence_1w,      kSTlookhouse_1w,       kSTlookwindow_1w,      kSTlookmoon_1w,
	kSTeatpumpkin_1w,     kSTundermat_1w,       kSTlookscreen1_1w,     kSTlookbat_1w,         kSTlookpicture_1w,
	kSTlooktable_1w,      kSTlookupstairs_1w,   kSTlooklight_1w,       kSTlistenhall_1w,      kSTlookscreen2_1w,
	kSTlookbed_1w,        kSTnosnooze_1w,       kSTlookward_1w,        kSTlookcupbd_1w,       kSTlookbed1win_1w,
	kSTlookface_1w,       kSTlookscreen3_1w,    kSTlookspread_1w,      kSTlookbutler_1w,      kSTlookplant_1w,
	kSTlookzelda_1w,      kSTlookdiningwin_1w,  kSTlookfood_1w,        kSTlookdiningman_1w,   kSTlookwoman_1w,
	kSTsitdown_1w,        kSTtakefood_1w,       kSTtalkdiningman_1w,   kSTtalkdiningwoman_1w, kSTtalkbutler_1w,
	kSTskiss_1w,          kSTlistendining_1w,   kSTdrinkdining_1w,     kSTlookscreen4_1w,     kSTlookbathwin_1w,
	kSTlookmirror_1w,     kSTlooktoilet_1w,     kSTdopoo_1w,           kSTdowee_1w,           kSTlooktub_1w,
	kSTusetub_1w,         kSTsittoilet_1w,      kSTwashhands_1w,       kSTlookscreen5_1w,     kSTlookunits_1w,
	kSTlookkitchenwin_1w, kSTlookbroom_1w,      kSTtakebroom_1w,       kSTridebroom_1w,       kSTsweepbroom_1w,
	kSTlistenkitchen_1w,  kSTlookscreen6_1w,    kSTlookShed_1w,        kSTclimbtree_1w,       kSTlookgarden_1w,
	kSTlookscreen7_1w,    kSTsayunbolt_1w,      kSTlookmousehole_1w,   kSTtakedroppings_1w,   kSTlookscreen8_1w,
	kSTlookbasedoor_1w,   kSToilbasedoor_1w,    kSTpushbasedoor_1w,    kSTexaminerock_1w,     kSTbreakbasedoor_1w,
	kSTopenbasedoor_1w,   kSTunlockbasedoor_1w, kSTknockbasedoor_1w,   kSTtalkpenelope_1w,    kSTlistenbase_1w,
	kSTlookscreen9_1w,    kSTlookrock_1w,       kSTlookscreen10_1w,    kSTlooktomb_1w,        kSTlookscreen11_1w,
	kSTsuggestboat_1w,    kSTnotthirsty_1w,     kSTqueryplug_1w,       kSTlookscreen12_1w,    kSTtalkguard_1w,
	kSTlookscreen15_1w,   kSTtalkigor_1w,       kSTtalkprof_1w,        kSTlookmachine_1w,     kSTusemachine_1w,
	kSTlookbooth_1w,      kSTlooklabtable_1w,   kSTuseboxdoor_1w,      kSTlooklights_1w,      kSTspbreak_1w,
	kSTsseepk_1w,         kSTsseedw_1w,         kSTsseepkdw_1w,        kSTesnosee_1w,         kSTesthrown_1w,
	kSTsWonder_1w,        kSTsBlowWhistle_1w,   kSTsdefbat1_1w,        kSTsdefbat2_1w,        kSTsNothing_1w,
	kSTsDropMask_1w,      kSTsbut1_1w,          kSTsButSniff_1w,       kSTsButChop_1w,        kSTsButHead_1w,
	kSTsButEnjoy_1w,      kSTsButTake_1w,       kSTsButLater_1w,       kSTsChopPrompt_1w,     kSTsEatChop_1w,
	kSTsDogEat_1w,        kSTsopenp_1w,         kSTsopenr_1w,          kSTsWrongCombo_1w,     kSTsRightCombo_1w,
	kSTsDogEatHero_1w,    kSTsTossMask_1w,      kSTsTrapBolted_1w,     kSTshelpp1_1w,         kSTsBaseHelp1_1w,
	kSTsNoHelp_1w,        kSTshelpp2_1w,        kSTsBaseHelp2_1w,      kSTsGotcher_1w,        kSTsBatGot_1w,
	kSTsMummyGot_1w,      kSTsBoatHole_1w,      kSTsManBlock_1w,       kSTsShutup_1w,         kSTsBoatTied_1w,
	kSTsq1_1w,            kSTsq2_1w,            kSTsq3_1w,             kSTsq4_1w,             kSTsq5_1w,
	kSTsq6_1w,            kSTsq7_1w,            kSTsrep1_1w,           kSTsrep2_1w,           kSTsrep3_1w,
	kSTsrep4_1w,          kSTsrep5_1w,          kSTsrep6_1w,           kSTsrep7_1w,           kSTsCorrect_1w,
	kSTsIncorrect_1w,     kSTsDoomed1_1w,       kSTsDoomed2_1w,        kSTsContinue_1w,       kSTsOldMan1_1w,
	kSTsOldMan2_1w,       kSTsOldMan3_1w,       kSTsOldMan4_1w,        kSTsOldMan5_1w,        kSTsCongrats_1w,
	kSTsRescued1_1w,      kSTsRescued2_1w,      kSTsRescued3_1w,       kSTsGuard1_1w,         kSTsGuard2_1w,
	kSTsNoGive_1w,        kSTsKissy_1w,         kSTsGoodbye_1w,        kSTsGrip_1w,           kSTsCoordinate_1w,
	kSTsReach_1w,         kSTsProf1_1w,         kSTsProf2_1w,          kSTsProf3_1w,          kSTsIgorRed_1w,
	kSTsProfUpset_1w,     kSTsProfRetires_1w,   kSTsIgorRefuses_1w,    kSTsIgorBlue_1w,       kSTsIgorGreen_1w,
	kSTsIgorYellow_1w,    kSTsIgorNo_1w,        kSTsIgorBox_1w,        kSTAskFrank_1w,        kSTRepFrank_1w,
	kSTAskDrac_1w,        kSTRepDrac_1w,        kSTAskGwen_1w,         kSTRepGwen_1w,         kSTAskFriar_1w,
	kSTRepFriar_1w,       kSTAskSlime_1w,       kSTRepSlime_1w,        kSTAskPea_1w,          kSTRepPea_1w,
	kSTclimbtree1_1w,     kSTclimbfence_1w,     kSTWearMask_1w,        kSTRemoveMask_1w,      kSTStrokeDog_1w,
	kSTCutHero_1w,        kSTOilHero_1w,        kSTsTakeOil_1w,        kSTsEnterBoat_1w,      kSTsExitBoat_1w,
	kSTsBoatAsk_1w,       kSTGoldHero_1w,       kSTLookMummy_1w,       kSTTalkMummy_1w,       kSTLookCarpet_1w,
	kSTLookMonkey_1w
};

enum string_t_2w {
//Hugo2
	kSTOkgen_2w,        kSTNopurps_2w,    kSTClick_2w,         kSTNocarry_2w,     kSTEmpty_2w,
	kSTMorespecific_2w, kSTStory_2w,      kSTSmaid1_1_2w,      kSTSmaid1_2_2w,    kSTSmaid1_3_2w,
	kSTSmaid1_4_2w,     kSTSmaid1_5_2w,   kSTSmaid1_6_2w,      kSTSmaid1_7_2w,    kSTSmaid1_8_2w,
	kSTSmaid1_9_2w,     kSTSmaid1_10_2w,  kSTSfirst_2w,        kSTTired_2w,       kSTTired2_2w,
	kSTSfaint1_2w,      kSTSfaint2_2w,    kSTSfaint3_2w,       kSTSfaint4_2w,     kSTFirst2_2w,
	kSTSgone1_2w,       kSTSgone2_2w,     kSTSgone3_2w,        kSTSgone4_2w,      kSTSgone5_2w,
	kSTSgone6_2w,       kSTSgone7_2w,     kSTHole1_2w,         kSTLock1_2w,       kSTDumb1_2w,
	kSTDumb2_2w,        kSTMatch1_2w,     kSTMatch2_2w,        kSTArgue1_2w,      kSTCook1_2w,
	kSTCook2_2w,        kSTCook3_2w,      kSTCook4_2w,         kSTCook5_2w,       kSTSgard1_2w,
	kSTSgard2_2w,       kSTSgard3_2w,     kSTSgard4_2w,        kSTSgard5_2w,      kSTSgard6_2w,
	kSTSgarl1_2w,       kSTSgarl2_2w,     kSTPush1_2w,         kSTRumble_2w,      kSTSwarn_2w,
	kSTStung_2w,        kSTMatch4_2w,     kSTSwarnz_2w,        kSTStingeroo_2w,   kSTSbug5b_2w,
	kSTSom1_2w,         kSTSom2_2w,       kSTSom3_2w,          kSTSom3a_2w,       kSTSom4_2w,
	kSTSom5_2w,         kSTSom6_2w,       kSTSom7_2w,          kSTSom8_2w,        kSTWell1_2w,
	kSTSnake1_2w,       kSTSnake2_2w,     kSTSnake3_2w,        kSTSnake4_2w,      kSTSnake5_2w,
	kSTSserum1_2w,      kSTSserum2_2w,    kSTSdial1_2w,        kSTSdial2_2w,      kSTSafepr_2w,
	kSTCall1_2w,        kSTCall2_2w,      kSTCall3_2w,         kSTCall4_2w,       kSTCall5_2w,
	kSTCall6_2w,        kSTTard1_2w,      kSTTard2_2w,         kSTBrrr_2w,        kSTWeee_2w,
	kSTThrown_2w,       kSTDyn1_2w,       kSTDyn2_2w,          kSTDyn3_2w,        kSTDyn4_2w,
	kSTDyn5_2w,         kSTDyn6_2w,       kSTDyn7_2w,          kSTDyn8_2w,        kSTDyn9_2w,
	kSTRub1_2w,         kSTRub2_2w,       kSTChasm1_2w,        kSTBanana1_2w,     kSTBanana2_2w,
	kSTTrap1_2w,        kSTSsafe1_2w,     kSTScomb1_2w,        kSTScomb2_2w,      kSTGotWill_2w,
	kSTSwill1_2w,       kSTSwill2_2w,     kSTSwill3_2w,        kSTSwill4_2w,      kSTSclimax1_2w,
	kSTSclimax2_2w,     kSTSclimax3_2w,   kSTSclimax4_2w,      kSTSclimax5_2w,    kSTSclimax6_2w,
	kSTSclimax7_2w,     kSTNobody_2w,     kSTNo_one1_2w,       kSTNo_one2_2w,     kSTSharry_2w,
	kSTScheat1_2w,      kSTScheat2_2w,    kSTSdidnt1_2w,       kSTSdidnt2_2w,     kSTSphoto_2w,
	kSTSphoto1_2w,      kSTBlah_2w,       kSTMaid1_2w,         kSTMaid2_2w,       kSTMaid3_2w,
	kSTMaid4_2w,        kSTMaid5_2w,      kSTBell1_2w,         kSTBell2_2w,       kSTMaid6_2w,
	kSTMaid7_2w,        kSTMaid8_2w,      kSTCat1_2w,          kSTCat2_2w,        kSTCat3_2w,
	kSTSridkey_2w,      kSTSpen1_2w,      kSTSpen2_2w,         kSTSpen3_2w,       kSTSdone1_2w,
	kSTSdone2_2w,       kSTSdone3_2w,     kSTSdone4_2w,        kSTSdone5_2w,      kSTSdone6_2w,
	kSTSdone7_2w,       kSTOrgan1_2w,     kSTOrgan2_2w,        kSTOrgan3_2w,      kSTOrgan4_2w,
	kSTNod1_2w,         kSTSay1_2w,       kSTSay2_2w,          kSTHest1_2w,       kSTHest2_2w,
	kSTHest3_2w,        kSTHest4_2w,      kSTHest5_2w,         kSTHest6_2w,       kSTHest7_2w,
	kSTHest8_2w,        kSTHest9_2w,      kSTShest1_2w,        kSTYes_2w,         kSTFire1_2w,
	kSTFire2_2w,        kSTFire3_2w,      kSTSrobot1_2w,       kSTSrobot2_2w,     kSTSrobot3_2w,
	kSTSsonic1_2w,      kSTSsonic2_2w,    kSTSsonic3_2w,       kSTSsonic4_2w,     kSTLookpen_2w,
	kSTMmmm_2w,         kSTHeadache_2w,   kSTSplant_2w,        kSTSpicture_2w,    kSTDull_2w,
	kSTNo_on_2w,        kSTSjump_2w,      kSTTrywalk_2w,       kSTNothing_2w,     kSTNoidea_2w,
	kSTNospecial_2w,    kSTSsearch_2w,    kSTNowayhose_2w,     kSTNounder_2w,     kSTLookover_2w,
	kSTNouse_2w,        kSTNosee_2w,      kSTTmaiddoor_2w,     kSTSclimb_2w,      kSTStalk_2w,
	kSTSattack_2w,      kSTSbreak_2w,     kSTQuiet_2w,         kSTAroma_2w,       kSTFalling_2w,
	kSTShelp_2w,        kSTSmagic_2w,     kSTSdig_2w,          kSTSrude_2w,       kSTNoanswer_2w,
	kSTWontopen_2w,     kSTCantunlock_2w, kSTHi_2w,            kSTNothanks_2w,    kSTWelcome_2w,
	kSTTmaid_2w,        kSTChatmaid1_2w,  kSTChatmaid2_2w,     kSTChatmaid3_2w,   kSTRudemaid_2w,
	kSTSdoor_2w,        kSTLookhall_2w,   kSTS2bed_2w,         kSTLookbed1_2w,    kSTLookbed_2w,
	kSTZzzz_2w,         kSTS3phone_2w,    kSTS3dumb_2w,        kSTS3bird_2w,      kSTLookbed2_2w,
	kSTParrot_2w,       kSTSbutton_2w,    kSTSinto_2w,         kSTLooklook_2w,    kSTLookbed3_2w,
	kSTS6garden_2w,     kSTS6dull_2w,     kSTLookkitchen_2w,   kSTLookback_2w,    kSTLookwin_2w,
	kSTLookshed_2w,     kSTLookatshed_2w, kSTS9tools1_2w,      kSTS9tools2_2w,    kSTLookinshed_2w,
	kSTSomebuttons_2w,  kSTMore_2w,       kSTRudeshed_2w,      kSTIgnore_2w,      kSTShedclose_2w,
	kSTLookvenus_2w,    kSTLookFly_2w,    kSTLookTrap_2w,      kSTS11look_2w,     kSTS12look_2w,
	kSTS13look_2w,      kSTS14look_2w,    kSTS15look_2w,       kSTS15wand1_2w,    kSTS15wand2_2w,
	kSTNoreply_2w,      kSTS16look_2w,    kSTNotclose_2w,      kSTS17look_2w,     kSTS17kill_2w,
	kSTS18look_2w,      kSTS19look_2w,    kSTS20look_2w,       kSTDonthaveone_2w, kSTS21look_2w,
	kSTTooheavy_2w,     kSTS22look_2w,    kSTS23look_2w,       kSTS24look_2w,     kSTS25look_2w,
	kSTS26look_2w,      kSTS27look_2w,    kSTS28look_2w,       kSTS28hole_2w,     kSTS28mouse_2w,
	kSTSdroppings_2w,   kSTS30look_2w,    kSTS31look_2w,       kSTS32look_2w,     kSTS33look_2w,
	kSTS35look_2w,      kSTS36book_2w,    kSTS36lookbook_2w,   kSTLookhest_2w,    kSTS37look_2w,
	kSTS38look_2w,      kSTDraught_2w,    kSTLookboxdoor_2w,   kSTDumbwaiter_2w,  kSTThrowmatch_2w,
	kSTGates1_2w,       kSTGates2_2w,     kSTGates3_2w,        kSTDull2_2w,       kSTWindwell_2w,
	kSTIntowell_2w,     kSTStrokedog_2w,  kSTBudge_2w,         kSTTalkgenie_2w,   kSTS36table_2w,
	kSTNotmirror_2w,    kSTPleasego_2w,   kSTComeHere_2w,      kSTUnlocksafe_2w,  kSTBalloon1_2w,
	kSTBalloon2_2w,     kSTBalloon3_2w,   kSTLookblocks_2w,    kSTSblock_2w,      kSTLookplaypen_2w,
	kSTStoobigtofit_2w, kSTReadpaper_2w,  kSTSherring_2w,      kSTTalkcook_2w,    kSTLookcook_2w,
	kSTLookknife_2w,    kSTTakeknife_2w,  kSTListenkitchen_2w, kSTNoswitch_2w,    kSTSnojump_2w,
	kSTNobanana_2w,     kSTSundress_2w,   kSTStired_2w,        kSTSstrokecat_2w,  kSTSplaycat_2w,
	kSTStalkcat_2w,     kSTSlookpost_2w,  kSTSgivecat_2w,      kSTSlookbox_2w,    kSTSgetinbox_2w,
	kSTLookchute_2w,    kSTUpchute_2w,    kSTPlayorgan_2w,     kSTLookOrgan_2w,   kSTTalkhester_2w,
	kSTSeatbanana_2w,   kSTBirdfull_2w,   kSTBlotter_2w,       kSTKeyhole2_2w,    kSTKeyhole3_2w,
	kSTGetonwithit_2w,  kSTRubcatnip1_2w, kSTRubcatnip2_2w,    kSTHearorgan_2w,   kSTHearlaugh_2w,
	kSTTryrope_2w,      kSTSclue09a_2w,   kSTSclue09b_2w,      kSTSclue09c_2w,    kSTSexplainb_2w,
	kSTSgraf_2w,        kSTDoorStuck_2w,  kSTGarlicPrompt_2w,  kSTGardInShed_2w,  kSTGardShed_2w,
	kSTLookBridge_2w,   kSTSdialed_2w,    kSTBananaPrompt_2w,  kSTLookScrew_2w,   kSTLookMirror_2w,
	kSTLookPMaid_2w,    kSTTalkPMaid_2w,  kSTUsePencil_2w,     kSTDoCrossword_2w
};

enum string_t_3w {
//Hugo 3
	kSTOkgen_3w,        kSTNopurps_3w,     kSTClick_3w,          kSTNocarry_3w,        kSTNonecarried_3w,
	kSTGotit_3w,        kSTEmpty1_3w,      kSTMorespecific_3w,   kSTLookpen_3w,        kSTMmmm_3w,
	kSTHeadache_3w,     kSTSjump_3w,       kSTTrywalk_3w,        kSTSclimb_3w,         kSTStalk_3w,
	kSTSattack_3w,      kSTSbreak_3w,      kSTQuiet_3w,          kSTAroma_3w,          kSTFalling_3w,
	kSTShelp_3w,        kSTSmagic_3w,      kSTSdig_3w,           kSTSrude_3w,          kSTNoanswer_3w,
	kSTWontopen_3w,     kSTCantunlock_3w,  kSTHi_3w,             kSTNothanks_3w,       kSTNothing_3w,
	kSTNoidea_3w,       kSTNospecial_3w,   kSTSsearch_3w,        kSTSundress_3w,       kSTStired_3w,
	kSTNowayhose_3w,    kSTNounder_3w,     kSTLookover_3w,       kSTNouse_3w,          kSTNosee_3w,
	kSTDull_3w,         kSTNo_on_3w,       kSTSnaughty_3w,       kSTNotclose_3w,       kSTLookcrash_3w,
	kSTLookwfall_3w,    kSTLookwfall_b_3w, kSTLookwbase_3w,      kSTLookpath_ul_3w,    kSTLookbridge1_3w,
	kSTLookbridge2_3w,  kSTLookweb_3w,     kSTLookstream1_3w,    kSTLookstream2_3w,    kSTLookvillage_3w,
	kSTLookhut_out_3w,  kSTLookhut_in_3w,  kSTLookgarden_3w,     kSTLookclifftop_3w,   kSTLookoldman_3w,
	kSTLookcliff_3w,    kSTLookcamp_3w,    kSTLookturn_3w,       kSTLookplane_3w,      kSTLookslope_3w,
	kSTLookpath2_1_3w,  kSTLookpath2_2_3w, kSTLookcave1_3w,      kSTLookcave2_3w,      kSTBlk1_3w,
	kSTBlk2_3w,         kSTStep1_3w,       kSTDropCheese_3w,     kSTMouse1_3w,         kSTProd1_3w,
	kSTProd2_3w,        kSTMousefree_3w,   kSTScare1_3w,         kSTSleepy_3w,         kSTDarted_3w,
	kSTScared_3w,       kSTDammed_3w,      kSTCom0_3w,           kSTCom1_3w,           kSTCom2_3w,
	kSTCom3_3w,         kSTCom4_3w,        kSTCom5_3w,           kSTCom6_3w,           kSTCom7_3w,
	kSTCom8_3w,         kSTCom9_3w,        kSTGiveb1_3w,         kSTGiveb2_3w,         kSTRefuse_3w,
	kSTOldman0a_3w,     kSTOldman0b_3w,    kSTOldman1_3w,        kSTOldman2_3w,        kSTOldman3_3w,
	kSTOldman4_3w,      kSTOldman5_3w,     kSTOldmantakeball_3w, kSTOldmannotake_3w,   kSTWrong_3w,
	kSTNoremedy_3w,     kSTNofill_3w,      kSTFillord_3w,        kSTFillmagic_3w,      kSTEmptyord_3w,
	kSTEmptymagic_3w,   kSTDrinkno_3w,     kSTDrinkyes_3w,       kSTYummy_3w,          kSTCheesePrompt_3w,
	kSTCanttake_3w,     kSTMousegone_3w,   kSTPutitdown_3w,      kSTAsleep_3w,         kSTElewaking_3w,
	kSTWaterfalling_3w, kSTPenny1_3w,      kSTPenny2_3w,         kSTPenny3_3w,         kSTPenny4_3w,
	kSTPenny5_3w,       kSTSpider1_3w,     kSTSpider2_3w,        kSTSpider3_3w,        kSTHelp1_3w,
	kSTMission1_3w,     kSTMission2_3w,    kSTMission3_3w,       kSTMission4_3w,       kSTMission5_3w,
	kSTMission6_3w,     kSTSaylook_3w,     kSTYouarein_3w,       kSTTalkweb_3w,        kSTCantcross_3w,
	kSTListenfall_3w,   kSTToomuddy_3w,    kSTLookdocbits_3w,    kSTTakedocbits_3w,    kSTLookspider_3w,
	kSTTakespider_3w,   kSTLooksnake_3w,   kSTTakesnake_3w,      kSTLookinhut_3w,      kSTLookouthut_3w,
	kSTTakeincage_3w,   kSTLookhut_in2_3w, kSTLookshelfbits_3w,  kSTTakeshelfbits_3w,  kSTLookshelfbits2_3w,
	kSTLookfire_3w,     kSTCantlookin_3w,  kSTLookinfire_3w,     kSTTalkdoc_3w,        kSTTalkdoc2_3w,
	kSTTalkdoc3_3w,     kSTLookorchid_3w,  kSTTakeorchid_3w,     kSTCrossgarden_3w,    kSTLookpole_3w,
	kSTLookhut_3w,      kSTLookintohut_3w, kSTEatroast_3w,       kSTLookrock_3w,       kSTUnderrock_3w,
	kSTOntorock_3w,     kSTLookjungle_3w,  kSTBehindhut_3w,      kSTLookhyena_3w,      kSTStickpin_3w,
	kSTRefuseflask_3w,  kSTNostickpin_3w,  kSTMakeeffigy_3w,     kSTNomake_3w,         kSTLookinhole_3w,
	kSTTalkmouse_3w,    kSTPicklock_3w,    kSTGivemouse_3w,      kSTGetinpot_3w,       kSTEnd1_3w,
	kSTEnd2_3w,         kSTEnd3_3w,        kSTCantswim_3w,       kSTGot1_3w,           kSTGot2_3w,
	kSTCantcatch_3w,    kSTAdios1_3w,      kSTAdios2_3w,         kSTAdios3_3w,         kSTRubcrystal_3w,
	kSTRemedytip_3w,    kSTOldmantip_3w,   kSTMagictip_3w,       kSTDammedtip_3w,      kSTCubestip_3w,
	kSTMousetip_3w,     kSTSticktip_3w,    kSTModeltip_3w,       kSTPlanetip_3w,       kSTSwingtip_3w,
	kSTAttackghost_3w,  kSTBook1_3w,       kSTExor1_3w,          kSTExor2_3w,          kSTFoundbook_3w,
	kSTNospell_3w,      kSTExordone_3w,    kSTCavewarn_3w,       kSTThruwindow_3w,     kSTRideelephant_3w,
	kSTGetelephant_3w,  kSTShowmouse_3w,   kSTSwingbridge_3w,    kSTGetbridgevines_3w, kSTNoblow_3w,
	kSTIntofire_3w,     kSTTakegirl_3w,    kSTTakenative_3w,     kSTMakeoffer_3w,      kSTLookatweb_3w,
	kSTTakepenny_3w,    kSTTalkpenny_3w,   kSTBridgedown_3w,     kSTCantswing_3w,      kSTTakeghost_3w,
	kSTAllwrong_3w,     kSTTiedvine_3w,    kSTUntievine_3w,      kSTNottied_3w,        kSTMissed_3w,
	kSTStuckpin_3w,     kSTTakedoctor0_3w, kSTTakedoctor1_3w,    kSTVillagething_3w,   kSTTakething_3w,
	kSTBridgeprompt_3w, kSTNotip_3w,       kSTBridgetip_3w,      kSTLookele2_3w,       kSTNostick_3w,
	kSTNoclay_3w,       kSTLookwfall1_3w,  kSTLookwfall2_3w,     kSTOpenplanedoor_3w,  kSTYesResponse_3w,
	kSTNoResponse_3w,   kSTCagePrompt_3w,  kSTDartElephant_3w
};

enum string_t_1d {
	kSTdummy_1d,
//***************************************************************************
// Hugo 1 Dos - Not stored in a dat file!!!
//***************************************************************************
	kSTsnosee_1d,             kSTokgen_1d,        kSTspbreak_1d,       kSTsseepk_1d,          kSTsseedw_1d,
	kSTsseepkdw_1d,           kSTsthrown_1d,      kSTsdefbat1_1d,      kSTsdefbat2_1d,        kSTsbut1_1d,
	kSTsbut2_1d,              kSTsopenp_1d,       kSTsopenr_1d,        kSTshelpp1_1d,         kSTshelpp2_1d,
	kSTsq1_1d,                kSTsq2_1d,          kSTsq3_1d,           kSTsq4_1d,             kSTsq5_1d,
	kSTsq6_1d,                kSTsq7_1d,          kSTsrep1_1d,         kSTsrep2_1d,           kSTsrep3_1d,
	kSTsrep4_1d,              kSTsrep5_1d,        kSTsrep6_1d,         kSTtrywalk_1d,         kSTnothing_1d,
	kSTnopurps_1d,            kSTnoidea_1d,       kSTdull_1d,          kSTempty_1d,           kSTchop1_1d,
	kSTnowayhose_1d,          kSTnounder_1d,      kSTnojump_1d,        kSTnoclimb_1d,         kSTnotalk_1d,
	kSTnoattack_1d,           kSTnobreak_1d,      kSTnolisten_1d,      kSTnosmell_1d,         kSTnolook_1d,
	kSTnohelp_1d,             kSTlooks0tree_1d,   kSTlooks0fence_1d,   kSTlooks0house_1d,     kSTlooks0window_1d,
	kSTlooks0moon_1d,         kSTeats0pkin_1d,    kSTunders0carpet_1d, kSTlooks0_1d,          kSTlooks1bat_1d,
	kSTlooks1picture_1d,      kSTlooks1table_1d,  kSTlooks1stairs_1d,  kSTlooks1light_1d,     kSTlooks1_1d,
	kSTlistens1_1d,           kSTlooks2bed_1d,    kSTrides2bed_1d,     kSTlooks2ward_1d,      kSTlooks2cupb_1d,
	kSTlooks2window_1d,       kSTlooks2face_1d,   kSTlooks2_1d,        kSTlooks3table_1d,     kSTlooks3butler_1d,
	kSTlooks3plant_1d,        kSTlooks3witch_1d,  kSTlooks3window_1d,  kSTlooks3food_1d,      kSTlooks3man_1d,
	kSTlooks3woman_1d,        kSTlooks3_1d,       kSTsits3_1d,         kSTtakes3food_1d,      kSTtalks3man_1d,
	kSTtalks3woman_1d,        kSTtalkS3butler_1d, kSTkisss3_1d,        kSTlistens3_1d,        kSTdrinks3_1d,
	kSTlooks4mirror_1d,       kSTlooks4toilet_1d, kSTlooks4_1d,        kSTcraps4_1d,          kSTsits4_1d,
	kSTwashs4hands_1d,        kSTlooks5units_1d,  kSTlooks5window_1d,  kSTlooks5broom_1d,     kSTtakes5broom_1d,
	kSTrides5broom_1d,        kSTlooks5_1d,       kSTsweeps5_1d,       kSTlooks6sched_1d,     kSTclimbs6tree_1d,
	kSTlooks6gardenbits_1d,   kSTlooks6_1d,       kSTunbolts7trap_1d,  kSTlooks7mousehole_1d, kSTtakes7droppings_1d,
	kSTlooks7_1d,             kSTlooks8door_1d,   kSToils8door_1d,     kSTpushs8door_1d,      kSTlooks8rock_1d,
	kSTbreaks8door_1d,        kSTopens8door_1d,   kSTunlocks8door_1d,  kSTknocks8door_1d,     kSTtalks8penelope_1d,
	kSTlistens8_1d,           kSTlooks8_1d,       kSTlooks9_1d,        kSTlooks9rock_1d,      kSTlooks10_1d,
	kSTlooks10tomb_1d,        kSTlooks11_1d,      kSTlakeverbss11_1d,  kSTplugs11_1d,         kSTlooks12_1d,
	kSTtalks12guard_1d,       kSTlooks15_1d,      kSTtalks15igor_1d,   kSTtalks15prof_1d,     kSTlooks15machinebits_1d,
	kSTpushs15machinebits_1d, kSTlooks15table_1d, kSTopens15door_1d,   kSTlooks15light_1d,    kSTsadwwhy_1d,
	kSTsablowt_1d,            kSTsanought_1d,     kSTsa115e_1d,        kSTsabut6a_1d,         kSTsabut6b_1d,
	kSTsabut6c_1d,            kSTsabut9a_1d,      kSTsabut9b_1d,       kSTsabut11_1d,         kSTsaeatchop_1d,
	kSTsachopthrown_1d,       kSTsanoopen_1d,     kSTsaopen4_1d,       kSTsadoggy4_1d,        kSTsat78a_1d,
	kSTsaopenfail_1d,         kSTsahelps1_1d,     kSTsanohelp_1d,      kSTsahelps2_1d,        kSTsabat5a_1d,
	kSTsabat5b_1d,            kSTsamum4_1d,       kSTsabung1_1d,       kSTsanodeboat_1d,      kSTsamoving_1d,
	kSTsanotcut_1d,           kSTsarepyep_1d,     kSTsarepnop_1d,      kSTsamans1_1d,         kSTsarepno5_1d,
	kSTsarepyep2_1d,          kSTsamans3_1d,      kSTsamans4_1d,       kSTsamans5_1d,         kSTsamans6_1d,
	kSTsamans7_1d,            kSTsajails1_1d,     kSTsajails2_1d,      kSTsajails3_1d,        kSTsajails4_1d,
	kSTsagive1_1d,            kSTsagive2_1d,      kSTsanogive_1d,      kSTsabye1_1d,          kSTsadmsg3_1d,
	kSTsadmsg2_1d,            kSTsadmsg1_1d,      kSTsalab12_1d,       kSTsalab13_1d,         kSTsabox2_1d,
	kSTsabox3_1d,             kSTsabox5_1d,       kSTsabox6_1d,        kSTsainorm_1d,         kSTsaigor32_1d,
	kSTsaigor22_1d,           kSTsaigor13_1d,     kSTsaigor0_1d,       kSTsagobox_1d,         kSTsknock_1d,
	kSTnomagic_1d,            kSTnodig_1d,        kSTnorude_1d,        kSTnoknock_1d
};

enum string_t_2d {
//Hugo 2 DOS
	kSTOkgen_2d,         kSTNopurps_2d,     kSTClick_2d,      kSTNocarry_2d,      kSTEmpty_2d,
	kSTMorespecific_2d,  kSTStory_2d,       kSTStory1_2d,     kSTSmaid1_1_2d,     kSTSmaid1_2_2d,
	kSTSmaid1_3_2d,      kSTSmaid1_4_2d,    kSTSmaid1_5_2d,   kSTSmaid1_6_2d,     kSTSmaid1_7_2d,
	kSTSmaid1_8_2d,      kSTSmaid1_9_2d,    kSTSmaid1_10_2d,  kSTSfirst_2d,       kSTTired_2d,
	kSTTired2_2d,        kSTSfaint1_2d,     kSTSfaint2_2d,    kSTSfaint3_2d,      kSTSfaint4_2d,
	kSTFirst2_2d,        kSTSgone1_2d,      kSTSgone2_2d,     kSTSgone3_2d,       kSTSgone4_2d,
	kSTSgone5_2d,        kSTSgone6_2d,      kSTSgone7_2d,     kSTHole1_2d,        kSTLock1_2d,
	kSTDumb1_2d,         kSTDumb2_2d,       kSTMatch1_2d,     kSTMatch2_2d,       kSTMatch3_2d,
	kSTArgue1_2d,        kSTCook1_2d,       kSTCook2_2d,      kSTCook3_2d,        kSTCook4_2d,
	kSTCook5_2d,         kSTSgard1_2d,      kSTSgard2_2d,     kSTSgard3_2d,       kSTSgard4_2d,
	kSTSgard5_2d,        kSTSgard6_2d,      kSTSgarl1_2d,     kSTSgarl2_2d,       kSTPush1_2d,
	kSTRumble_2d,        kSTSwarn_2d,       kSTStung_2d,      kSTMatch4_2d,       kSTSwarnz_2d,
	kSTStingeroo_2d,     kSTSbug5b_2d,      kSTSom1_2d,       kSTSom2_2d,         kSTSom3_2d,
	kSTSom3a_2d,         kSTSom4_2d,        kSTSom5_2d,       kSTSom6_2d,         kSTSom7_2d,
	kSTSom8_2d,          kSTWell1_2d,       kSTSnake1_2d,     kSTSnake2_2d,       kSTSnake3_2d,
	kSTSnake4_2d,        kSTSnake5_2d,      kSTSserum1_2d,    kSTSserum2_2d,      kSTSdial1_2d,
	kSTSdial2_2d,        kSTSafepr_2d,      kSTCall1_2d,      kSTCall2_2d,        kSTCall3_2d,
	kSTCall4_2d,         kSTCall5_2d,       kSTCall6_2d,      kSTTard1_2d,        kSTTard2_2d,
	kSTBrrr_2d,          kSTWeee_2d,        kSTDyn1_2d,       kSTDyn2_2d,         kSTDyn3_2d,
	kSTDyn4_2d,          kSTDyn5_2d,        kSTDyn6_2d,       kSTDyn7_2d,         kSTDyn8_2d,
	kSTDyn9_2d,          kSTRub1_2d,        kSTRub2_2d,       kSTChasm1_2d,       kSTBanana1_2d,
	kSTBanana2_2d,       kSTTrap1_2d,       kSTSsafe1_2d,     kSTScomb1_2d,       kSTScomb2_2d,
	kSTSwill1_2d,        kSTSwill2_2d,      kSTSwill3_2d,     kSTSwill4_2d,       kSTSclimax1_2d,
	kSTSclimax2_2d,      kSTSclimax3_2d,    kSTSclimax4_2d,   kSTSclimax5_2d,     kSTSclimax6_2d,
	kSTSclimax7_2d,      kSTNobody_2d,      kSTNo_one1_2d,    kSTNo_one2_2d,      kSTSharry_2d,
	kSTScheat1_2d,       kSTScheat2_2d,     kSTSdidnt1_2d,    kSTSdidnt2_2d,      kSTSphoto_2d,
	kSTSphoto1_2d,       kSTBlah_2d,        kSTMaid1_2d,      kSTMaid2_2d,        kSTMaid3_2d,
	kSTMaid4_2d,         kSTMaid5_2d,       kSTBell1_2d,      kSTBell2_2d,        kSTMaid6_2d,
	kSTMaid7_2d,         kSTMaid8_2d,       kSTCat1_2d,       kSTCat2_2d,         kSTCat3_2d,
	kSTSridkey_2d,       kSTSpen1_2d,       kSTSpen2_2d,      kSTSpen3_2d,        kSTSdone1_2d,
	kSTSdone2_2d,        kSTSdone3_2d,      kSTSdone4_2d,     kSTSdone5_2d,       kSTSdone6_2d,
	kSTOrgan1_2d,        kSTOrgan2_2d,      kSTOrgan3_2d,     kSTOrgan4_2d,       kSTNod1_2d,
	kSTSay1_2d,          kSTSay2_2d,        kSTHest1_2d,      kSTHest2_2d,        kSTHest3_2d,
	kSTHest4_2d,         kSTHest5_2d,       kSTHest6_2d,      kSTHest7_2d,        kSTHest8_2d,
	kSTHest9_2d,         kSTShest1_2d,      kSTYes_2d,        kSTFire1_2d,        kSTFire2_2d,
	kSTFire3_2d,         kSTSdalek1_2d,     kSTSdalek2_2d,    kSTSdalek3_2d,      kSTSsonic1_2d,
	kSTSsonic2_2d,       kSTSsonic3_2d,     kSTSsonic4_2d,    kSTLookpen_2d,      kSTMmmm_2d,
	kSTHeadache_2d,      kSTSplant_2d,      kSTSpicture_2d,   kSTDull_2d,         kSTNo_on_2d,
	kSTSjump_2d,         kSTTrywalk_2d,     kSTNothing_2d,    kSTNoidea_2d,       kSTNospecial_2d,
	kSTSsearch_2d,       kSTNowayhose_2d,   kSTNounder_2d,    kSTLookover_2d,     kSTNouse_2d,
	kSTNosee_2d,         kSTTmaiddoor_2d,   kSTSclimb_2d,     kSTStalk_2d,        kSTSattack_2d,
	kSTSbreak_2d,        kSTQuiet_2d,       kSTAroma_2d,      kSTFalling_2d,      kSTShelp_2d,
	kSTSmagic_2d,        kSTSdig_2d,        kSTSrude_2d,      kSTNoanswer_2d,     kSTWontopen_2d,
	kSTCantunlock_2d,    kSTHi_2d,          kSTNothanks_2d,   kSTWelcome_2d,      kSTTmaid_2d,
	kSTChatmaid1_2d,     kSTChatmaid2_2d,   kSTChatmaid3_2d,  kSTRudemaid_2d,     kSTSdoor_2d,
	kSTLookhall_2d,      kSTS2bed_2d,       kSTLookbed1_2d,   kSTLookbed_2d,      kSTZzzz_2d,
	kSTS3phone_2d,       kSTS3dumb_2d,      kSTS3bird_2d,     kSTLookbed2_2d,     kSTParrot_2d,
	kSTSbutton_2d,       kSTSinto_2d,       kSTLooklook_2d,   kSTLookbed3_2d,     kSTS6garden_2d,
	kSTS6dull_2d,        kSTLookkitchen_2d, kSTLookback_2d,   kSTLookwin_2d,      kSTLookshed_2d,
	kSTLookatshed_2d,    kSTS9tools1_2d,    kSTS9tools2_2d,   kSTLookinshed_2d,   kSTSomebuttons_2d,
	kSTMore_2d,          kSTRudeshed_2d,    kSTIgnore_2d,     kSTShedclose_2d,    kSTLookvenus_2d,
	kSTS11look_2d,       kSTS12look_2d,     kSTS13look_2d,    kSTS14look_2d,      kSTS15look_2d,
	kSTS15wand1_2d,      kSTS15wand2_2d,    kSTNoreply_2d,    kSTS16look_2d,      kSTNotclose_2d,
	kSTS17look_2d,       kSTS17kill_2d,     kSTS18look_2d,    kSTS19look_2d,      kSTS20look_2d,
	kSTDonthaveone_2d,   kSTS21look_2d,     kSTTooheavy_2d,   kSTS22look_2d,      kSTS23look_2d,
	kSTS24look_2d,       kSTS25look_2d,     kSTS26look_2d,    kSTS27look_2d,      kSTS28look_2d,
	kSTS28hole_2d,       kSTS28mouse_2d,    kSTSdroppings_2d, kSTS30look_2d,      kSTS31look_2d,
	kSTS32look_2d,       kSTS33look_2d,     kSTS35look_2d,    kSTS36book_2d,      kSTLookhest_2d,
	kSTS37look_2d,       kSTS38look_2d,     kSTDraught_2d,    kSTLookboxdoor_2d,  kSTDumbwaiter_2d,
	kSTThrowmatch_2d,    kSTGates1_2d,      kSTGates2_2d,     kSTGates3_2d,       kSTDull2_2d,
	kSTWindwell_2d,      kSTIntowell_2d,    kSTStrokedog_2d,  kSTBudge_2d,        kSTTalkgenie_2d,
	kSTS36table_2d,      kSTNotmirror_2d,   kSTPleasego_2d,   kSTUnlocksafe_2d,   kSTBalloon1_2d,
	kSTBalloon2_2d,      kSTBalloon3_2d,    kSTSblock_2d,     kSTStoobigtofit_2d, kSTReadpaper_2d,
	kSTSherring_2d,      kSTTalkcook_2d,    kSTLookcook_2d,   kSTLookknife_2d,    kSTTakeknife_2d,
	kSTListenkitchen_2d, kSTNoswitch_2d,    kSTSnojump_2d,    kSTNobanana_2d,     kSTSundress_2d,
	kSTStired_2d,        kSTSstrokecat_2d,  kSTSplaycat_2d,   kSTStalkcat_2d,     kSTSlookpost_2d,
	kSTSgivecat_2d,      kSTSlookbox_2d,    kSTSgetinbox_2d,  kSTLookchute_2d,    kSTUpchute_2d,
	kSTPlayorgan_2d,     kSTTalkhester_2d,  kSTSeatbanana_2d, kSTBirdfull_2d,     kSTBlotter_2d,
	kSTGetonwithit_2d,   kSTRubcatnip1_2d,  kSTRubcatnip2_2d, kSTHearorgan_2d,    kSTHearlaugh_2d,
	kSTTryrope_2d,       kSTSclue09a_2d,    kSTSclue09b_2d,   kSTSclue09c_2d,     kSTSexplainb_2d,
	kSTSgraf_2d
};

enum string_t_3d {
//Hugo 3 DOS
	kSTOkgen_3d,          kSTNopurps_3d,       kSTClick_3d,          kSTNocarry_3d,        kSTNonecarried_3d,
	kSTGotit_3d,          kSTEmpty1_3d,        kSTMorespecific_3d,   kSTLookpen_3d,        kSTMmmm_3d,
	kSTHeadache_3d,       kSTSjump_3d,         kSTTrywalk_3d,        kSTSclimb_3d,         kSTStalk_3d,
	kSTSattack_3d,        kSTSbreak_3d,        kSTQuiet_3d,          kSTAroma_3d,          kSTFalling_3d,
	kSTShelp_3d,          kSTSmagic_3d,        kSTSdig_3d,           kSTSrude_3d,          kSTNoanswer_3d,
	kSTWontopen_3d,       kSTCantunlock_3d,    kSTHi_3d,             kSTNothanks_3d,       kSTNothing_3d,
	kSTNoidea_3d,         kSTNospecial_3d,     kSTSsearch_3d,        kSTSundress_3d,       kSTStired_3d,
	kSTNowayhose_3d,      kSTNounder_3d,       kSTLookover_3d,       kSTNouse_3d,          kSTNosee_3d,
	kSTDull_3d,           kSTNo_on_3d,         kSTSnaughty_3d,       kSTNotclose_3d,       kSTLookcrash_3d,
	kSTLookwfall_3d,      kSTLookwfall_b_3d,   kSTLookwbase_3d,      kSTLookpath_ul_3d,    kSTLookbridge1_3d,
	kSTLookbridge2_3d,    kSTLookweb_3d,       kSTLookstream1_3d,    kSTLookstream2_3d,    kSTLookvillage_3d,
	kSTLookhut_out_3d,    kSTLookhut_in_3d,    kSTLookgarden_3d,     kSTLookclifftop_3d,   kSTLookoldman_3d,
	kSTLookcliff_3d,      kSTLookcamp_3d,      kSTLookturn_3d,       kSTLookplane_3d,      kSTLookslope_3d,
	kSTLookpath2_1_3d,    kSTLookpath2_2_3d,   kSTLookcave1_3d,      kSTLookcave2_3d,      kSTBlk1_3d,
	kSTBlk2_3d,           kSTStep1_3d,         kSTMouse1_3d,         kSTProd1_3d,          kSTProd2_3d,
	kSTMousefree_3d,      kSTScare1_3d,        kSTSleepy_3d,         kSTDarted_3d,         kSTScared_3d,
	kSTDammed_3d,         kSTCom0_3d,          kSTCom1_3d,           kSTCom2_3d,           kSTCom3_3d,
	kSTCom4_3d,           kSTCom5_3d,          kSTCom6_3d,           kSTCom7_3d,           kSTCom8_3d,
	kSTCom9_3d,           kSTGiveb1_3d,        kSTGiveb2_3d,         kSTRefuse_3d,         kSTOldrsp1_3d,
	kSTOldman0a_3d,       kSTOldman0b_3d,      kSTOldman1_3d,        kSTOldman2_3d,        kSTOldman3_3d,
	kSTOldman4_3d,        kSTOldman5_3d,       kSTOldmantakeball_3d, kSTOldmannotake_3d,   kSTWrong_3d,
	kSTNoremedy_3d,       kSTNofill_3d,        kSTFillord_3d,        kSTFillmagic_3d,      kSTEmptyord_3d,
	kSTEmptymagic_3d,     kSTDrinkno_3d,       kSTDrinkyes_3d,       kSTYummy_3d,          kSTCanttake_3d,
	kSTMousegone_3d,      kSTPutitdown_3d,     kSTAsleep_3d,         kSTElewaking_3d,      kSTWaterfalling_3d,
	kSTPenny1_3d,         kSTPenny2_3d,        kSTPenny3_3d,         kSTPenny4_3d,         kSTPenny5_3d,
	kSTSpider1_3d,        kSTSpider2_3d,       kSTSpider3_3d,        kSTHelp1_3d,          kSTMission1_3d,
	kSTMission2_3d,       kSTMission3_3d,      kSTMission4_3d,       kSTMission5_3d,       kSTMission6_3d,
	kSTSaylook_3d,        kSTYouarein_3d,      kSTTalkweb_3d,        kSTCantcross_3d,      kSTListenfall_3d,
	kSTToomuddy_3d,       kSTLookdocbits_3d,   kSTTakedocbits_3d,    kSTLookspider_3d,     kSTTakespider_3d,
	kSTLooksnake_3d,      kSTTakesnake_3d,     kSTLookinhut_3d,      kSTLookouthut_3d,     kSTTakeincage_3d,
	kSTLookhut_in2_3d,    kSTLookshelfbits_3d, kSTTakeshelfbits_3d,  kSTLookshelfbits2_3d, kSTLookfire_3d,
	kSTCantlookin_3d,     kSTLookinfire_3d,    kSTTalkdoc_3d,        kSTTalkdoc2_3d,       kSTLookorchid_3d,
	kSTTakeorchid_3d,     kSTCrossgarden_3d,   kSTLookpole_3d,       kSTLookhut_3d,        kSTLookintohut_3d,
	kSTEatroast_3d,       kSTLookrock_3d,      kSTUnderrock_3d,      kSTOntorock_3d,       kSTLookjungle_3d,
	kSTBehindhut_3d,      kSTLookhyena_3d,     kSTStickpin_3d,       kSTRefuseflask_3d,    kSTNostickpin_3d,
	kSTMakeeffigy_3d,     kSTNomake_3d,        kSTLookinhole_3d,     kSTTalkmouse_3d,      kSTPicklock_3d,
	kSTGivemouse_3d,      kSTGetinpot_3d,      kSTEnd1_3d,           kSTEnd2_3d,           kSTEnd3_3d,
	kSTCantswim_3d,       kSTGot1_3d,          kSTGot2_3d,           kSTCantcatch_3d,      kSTAdios1_3d,
	kSTAdios2_3d,         kSTRubcrystal_3d,    kSTRemedytip_3d,      kSTOldmantip_3d,      kSTMagictip_3d,
	kSTDammedtip_3d,      kSTCubestip_3d,      kSTMousetip_3d,       kSTSticktip_3d,       kSTModeltip_3d,
	kSTPlanetip_3d,       kSTSwingtip_3d,      kSTAttackghost_3d,    kSTBook1_3d,          kSTExor1_3d,
	kSTExor2_3d,          kSTFoundbook_3d,     kSTNospell_3d,        kSTExordone_3d,       kSTCavewarn_3d,
	kSTThruwindow_3d,     kSTRideelephant_3d,  kSTGetelephant_3d,    kSTShowmouse_3d,      kSTSwingbridge_3d,
	kSTGetbridgevines_3d, kSTNoblow_3d,        kSTIntofire_3d,       kSTTakegirl_3d,       kSTTakenative_3d,
	kSTMakeoffer_3d,      kSTLookatweb_3d,     kSTTakepenny_3d,      kSTTalkpenny_3d,      kSTBridgedown_3d,
	kSTCantswing_3d,      kSTTakeghost_3d,     kSTAllwrong_3d,       kSTTiedvine_3d,       kSTUntievine_3d,
	kSTNottied_3d,        kSTMissed_3d,        kSTStuckpin_3d,       kSTTakedoctor0_3d,    kSTTakedoctor1_3d,
	kSTVillagething_3d,   kSTTakething_3d,     kSTBridgeprompt_3d,   kSTTiprsp_3d,         kSTNotip_3d,
	kSTBridgetip_3d,      kSTLookele2_3d,      kSTNostick_3d,        kSTNoclay_3d,         kSTLookwfall1_3d,
	kSTLookwfall2_3d,     kSTOpenplanedoor_3d
};

enum seqReqList_1w {
//***************************************************************************
// Hugo 1 Windows
//***************************************************************************
	kRDummy = 0,
	kRkey_1w = 1, kRpkin_1w, kRcandle_1w, kRmask_1w, kRoil_1w,
	kRknife_1w,   kRbung_1w
};

enum seqReqList_2w {
//***************************************************************************
// Hugo 2 Windows
//***************************************************************************
	kRgarlic_2w = 1, kRmatch_2w,   kRstick_2w,   kRdyn_2w,   kRlamp_2w,
	kRbanana_2w,     kRbell_2w,    kRcatnip_2w,  kRgun_2w,   kRpaper_2w,
	kRpencil_2w,     kRmagnify_2w, kRwill_2w,    kRserum_2w
};

enum seqReqList_3w {
//***************************************************************************
// Hugo 3 Windows
//***************************************************************************
	kRpins_3w = 1, kRcheese_3w, kRcrystal_3w, kRexor_3w, kRbook_3w,
	kRbell_3w,     kRpipe_3w
};

enum seqReqList_1d {
//***************************************************************************
// Hugo 1 DOS
//***************************************************************************
	kRkey_1d = 1, kRpkin_1d, kRcandle_1d, kRmask_1d, kRoil_1d,
	kRknife_1d,   kRbung_1d
};

enum seqReqList_2d {
//***************************************************************************
// Hugo 2 DOS
//***************************************************************************
	kRgarlic_2d = 1, kRmatch_2d,   kRstick_2d,  kRdyn_2d,   kRlamp_2d,
	kRbanana_2d,     kRbell_2d,    kRcatnip_2d, kRgun_2d,   kRpaper_2d,
	kRpencil_2d,     kRmagnify_2d, kRwill_2d,   kRserum_2d
};

enum seqReqList_3d {
//***************************************************************************
// Hugo 3 DOS
//***************************************************************************
	kRpins_3d = 1, kRcheese_3d, kRcrystal_3d, kRexor_3d, kRbook_3d,
	kRbell_3d
};

enum cmdIdx_1w {
	kCMDDummy,     kCMDboat_1w,  kCMDbolt_1w,  kCMDbung_1w,  kCMDcarpet_1w,
	kCMDchop_1w,   kCMDcupb_1w,  kCMDdoor1_1w, kCMDdoor2_1w, kCMDdoor3_1w,
	kCMDdoor4_1w,  kCMDdrac_1w,  kCMDfrank_1w, kCMDgold_1w,  kCMDgwen_1w,
	kCMDhood_1w,   kCMDigor_1w,  kCMDknife_1w, kCMDmask_1w,  kCMDoilcan_1w,
	kCMDoldman_1w, kCMDpeahd_1w, kCMDpkin_1w,  kCMDrock_1w,  kCMDrope_1w,
	kCMDshed_1w,   kCMDslime_1w, kCMDtrap_1w,  kCMDward_1w,  kCMDwhistle_1w
};

enum cmdIdx_2w {
	kCMDalbum_2w = 1, kCMDballoon_2w,  kCMDbanana_2w,   kCMDbell_2w,    kCMDblue_2w,
	kCMDbook_2w,      kCMDbottle_2w,   kCMDbutton_2w,   kCMDcatnip_2w,  kCMDcupbp_2w,
	kCMDdoor1_2w,     kCMDdoor2_2w,    kCMDdoor3_2w,    kCMDdoordum_2w, kCMDdumb_2w,
	kCMDdynamite_2w,  kCMDgarlic_2w,   kCMDgreen_2w,    kCMDgun_2w,     kCMDharry_2w,
	kCMDkdoor_2w,     kCMDkennel_2w,   kCMDkeyhole_2w,  kCMDlamp_2w,    kCMDletter_2w,
	kCMDlookcupb_2w,  kCMDlookdesk_2w, kCMDlookgard_2w, kCMDmatches_2w, kCMDpaper_2w,
	kCMDpdoor_2w,     kCMDpencil_2w,   kCMDred_2w,      kCMDrobot_2w,   kCMDrope_2w,
	kCMDsafe_2w,      kCMDstick_2w,    kCMDtardis_2w,   kCMDwell_2w,    kCMDwill_2w,
	kCMDyellow_2w
};

enum cmdIdx_3w {
	kCMDcbell_3w = 1, kCMDcbook_3w,     kCMDcbouillon_3w, kCMDccage_3w,   kCMDccandle_3w,
	kCMDccheese_3w,   kCMDcclay_3w,     kCMDccrystal_3w,  kCMDcdart_3w,   kCMDcdoctor_3w,
	kCMDcdoor_3w,     kCMDcelephant_3w, kCMDcexit_3w,     kCMDcflask_3w,  kCMDcghost_3w,
	kCMDcnative_3w,   kCMDcpins_3w,     kCMDcplane_3w,    kCMDcrock_3w,   kCMDcrush_3w,
	kCMDcscroll_3w,   kCMDcsteps_3w,    kCMDcswing_3w,    kCMDcswingc_3w, kCMDcvine_3w,
	kCMDcwfall_3w,    kCMDcwpool_3w,    kCMDcwstream_3w
};

enum cmdIdx_1d {
	kCMDboat_1d = 1, kCMDbolt_1d,    kCMDbung_1d,  kCMDcarpet_1d, kCMDchop_1d,
	kCMDcupb_1d,     kCMDdoor1_1d,   kCMDdoor2_1d, kCMDdoor3_1d,  kCMDdoor4_1d,
	kCMDgold_1d,     kCMDigor_1d,    kCMDknife_1d, kCMDmask_1d,   kCMDoilcan_1d,
	kCMDoldman_1d,   kCMDpkin_1d,    kCMDrope_1d,  kCMDshed_1d,   kCMDtrap_1d,
	kCMDward_1d,     kCMDwhistle_1d
};

enum cmdIdx_2d {
	kCMDballoon_2d = 1, kCMDbanana_2d, kCMDbell_2d,   kCMDblue_2d,     kCMDbook_2d,
	kCMDbottle_2d,      kCMDbutton_2d, kCMDcatnip_2d, kCMDcupbp_2d,    kCMDdoor1_2d,
	kCMDdoor2_2d,       kCMDdoor3_2d,  kCMDdumb_2d,   kCMDdynamite_2d, kCMDgarlic_2d,
	kCMDgreen_2d,       kCMDgun_2d,    kCMDharry_2d,  kCMDkdoor_2d,    kCMDkennel_2d,
	kCMDkeyhole_2d,     kCMDlamp_2d,   kCMDletter_2d, kCMDlookcupb_2d, kCMDlookdesk_2d,
	kCMDmatches_2d,     kCMDpaper_2d,  kCMDpdoor_2d,  kCMDpencil_2d,   kCMDred_2d,
	kCMDrope_2d,        kCMDsafe_2d,   kCMDstick_2d,  kCMDtardis_2d,   kCMDwell_2d,
	kCMDwill_2d,        kCMDyellow_2d
};

enum cmdIdx_3d {
	kCMDcbell_3d = 1, kCMDcbook_3d,  kCMDcbouillon_3d, kCMDccage_3d,    kCMDccandle_3d,
	kCMDccheese_3d,   kCMDcclay_3d,  kCMDccrystal_3d,  kCMDcdart_3d,    kCMDcdoor_3d,
	kCMDcexit_3d,     kCMDcflask_3d, kCMDcghost_3d,    kCMDcnative_3d,  kCMDcpins_3d,
	kCMDcplane_3d,    kCMDcrock_3d,  kCMDcscroll_3d,   kCMDcswing_3d,   kCMDcswingc_3d,
	kCMDcvine_3d,     kCMDcwfall_3d, kCMDcwpool_3d,    kCMDcwstream_3d
};
// Enumerate the different path types for an object
enum path_t {
	USER,                                           // User has control of object via cursor keys
	AUTO,                                           // Computer has control, controlled by action lists
	QUIET,                                          // Computer has control and no commands allowed
	CHASE,                                          // Computer has control, object is chasing hero
	CHASE2,                                     // Same as CHASE, except keeps cycling when stationary
	WANDER,                                     // Computer has control, object is wandering randomly
	WANDER2                                     // Same as WANDER, except keeps cycling when stationary
};

#define PERSON    4, NULL, {{4, NULL}, {4, NULL}, {2, NULL}, {2, NULL}}
#define PERSON2   2, NULL, {{4, NULL}, {4, NULL}}
#define PERSON3   3, NULL, {{4, NULL}, {4, NULL}, {1, NULL}}
#define PERSON4   4, NULL, {{4, NULL}, {4, NULL}, {1, NULL}, {1, NULL}}
#define PERSON5   3, NULL, {{4, NULL}, {4, NULL}, {4, NULL}}
#define ANIMAL    4, NULL, {{3, NULL}, {3, NULL}, {1, NULL}, {1, NULL}}
#define THING0    0, NULL, {{0, NULL}}
#define THING1    1, NULL, {{1, NULL}}
#define THING2    1, NULL, {{2, NULL}}
#define THING3    1, NULL, {{3, NULL}}
#define THING4    1, NULL, {{4, NULL}}
#define THING2a   2, NULL, {{1, NULL}, {2, NULL}}
#define THING2b   2, NULL, {{2, NULL}, {2, NULL}}
#define THING2c   2, NULL, {{1, NULL}, {1, NULL}}
#define THING2d   2, NULL, {{1, NULL}, {4, NULL}}
#define THING2e   2, NULL, {{5, NULL}, {1, NULL}}
#define THING2f   2, NULL, {{2, NULL}, {3, NULL}}
#define THING2g   2, NULL, {{3, NULL}, {4, NULL}}
#define GO_OBJ  -1

enum cycle_t {INVISIBLE, ALMOST_INVISIBLE, NOT_CYCLING, CYCLE_FORWARD, CYCLE_BACKWARD};
// Piorities
enum {FOREGROUND, BACKGROUND, FLOATING, OVEROVL};

#define DX             5                            // Num pixels moved in x by HERO per step
#define DY             4                            // Num pixels moved in y by HERO per step

// Following defines the action types and action list
enum action_t {                                     // Parameters:
	ANULL              = 0xff,                      // Special NOP used to 'delete' events in DEL_EVENTS
	ASCHEDULE          = 0,                         //  0 - Ptr to action list to be rescheduled
	START_OBJ          = 1,                         //  1 - Object number
	INIT_OBJXY         = 2,                         //  2 - Object number, x,y
	PROMPT             = 3,                         //  3 - index of prompt & response string, ptrs to action
	// lists.  First if response matches, 2nd if not.
	BKGD_COLOR         = 4,                         //  4 - new background color
	INIT_OBJVXY        = 5,                         //  5 - Object number, vx, vy
	INIT_CARRY         = 6,                         //  6 - Object number, carried status
	INIT_HF_COORD      = 7,                         //  7 - Object number (gets hero's 'feet' coordinates)
	NEW_SCREEN         = 8,                         //  8 - New screen number
	INIT_OBJSTATE      = 9,                         //  9 - Object number, new object state
	INIT_PATH          = 10,                        // 10 - Object number, new path type
	COND_R             = 11,                        // 11 - Conditional on object state - req state, 2 act_lists
	TEXT               = 12,                        // 12 - Simple text box
	SWAP_IMAGES        = 13,                        // 13 - Swap 2 object images
	COND_SCR           = 14,                        // 14 - Conditional on current screen
	AUTOPILOT          = 15,                        // 15 - Set object to home in on another (stationary) object
	INIT_OBJ_SEQ       = 16,                        // 16 - Object number, sequence index to set curr_seq_p to
	SET_STATE_BITS     = 17,                        // 17 - Objnum, mask to OR with obj states word
	CLEAR_STATE_BITS   = 18,                        // 18 - Objnum, mask to ~AND with obj states word
	TEST_STATE_BITS    = 19,                        // 19 - Objnum, mask to test obj states word
	DEL_EVENTS         = 20,                        // 20 - Action type to delete all occurrences of
	GAMEOVER           = 21,                        // 21 - Disable hero & commands.  Game is over
	INIT_HH_COORD      = 22,                        // 22 - Object number (gets hero's actual coordinates)
	EXIT               = 23,                        // 23 - Exit game back to DOS
	BONUS              = 24,                        // 24 - Get score bonus for an action
	COND_BOX           = 25,                        // 25 - Conditional on object within bounding box
	SOUND              = 26,                        // 26 - Set currently playing sound
	ADD_SCORE          = 27,                        // 27 - Add object's value to current score
	SUB_SCORE          = 28,                        // 28 - Subtract object's value from current score
	COND_CARRY         = 29,                        // 29 - Conditional on carrying object
	INIT_MAZE          = 30,                        // 30 - Start special maze hotspot processing
	EXIT_MAZE          = 31,                        // 31 - Exit special maze processing
	INIT_PRIORITY      = 32,                        // 32 - Initialize fbg field
	INIT_SCREEN        = 33,                        // 33 - Initialize screen field of object
	AGSCHEDULE         = 34,                        // 34 - Global schedule - lasts over new screen
	REMAPPAL           = 35,                        // 35 - Remappe palette - palette index, color
	COND_NOUN          = 36,                        // 36 - Conditional on noun appearing in line
	SCREEN_STATE       = 37,                        // 37 - Set new screen state - used for comments
	INIT_LIPS          = 38,                        // 38 - Position lips object for supplied object
	INIT_STORY_MODE    = 39,                        // 39 - Set story mode TRUE/FALSE (user can't type)
	WARN               = 40,                        // 40 - Same as TEXT but can't dismiss box by typing
	COND_BONUS         = 41,                        // 41 - Conditional on bonus having been scored
	TEXT_TAKE          = 42,                        // 42 - Issue text box with "take" info string
	YESNO              = 43,                        // 43 - Prompt user for Yes or No
	STOP_ROUTE         = 44,                        // 44 - Skip any route in progress (hero still walks)
	COND_ROUTE         = 45,                        // 45 - Conditional on route in progress
	INIT_JUMPEXIT      = 46,                        // 46 - Initialize status.jumpexit
	INIT_VIEW          = 47,                        // 47 - Initialize viewx, viewy, dir
	INIT_OBJ_FRAME     = 48,                        // 48 - Object number, seq,frame to set curr_seq_p to
	OLD_SONG           = 49                         // Added by Strangerke - Set currently playing sound, old way: that is, using a string index instead of a reference in a file
};

// Enumerate object numbers.  ALL objects must have an entry here in order.
enum objid_1w {
	HERO = 0,    DOOR1_1w,    EYES1_1w,  EYES2_1w,    BAT_1w,      PKIN_1w,      KEY_1w,      FENCE_1w,   TREE1_1w,
	DOOR2_1w,    DOOR3_1w,    EYES3_1w,  EYES4_1w,    BATPIC_1w,   CANDLE_1w,    CUPBOARD_1w, KNIFE_1w,   WHISTLE_1w,
	WARD_1w,     WDOORL_1w,   WDOORR_1w, MASK_1w,     MONKEY_1w,   WINDOW1_1w,   BED_1w,      BUTLER_1w,  CHOP_1w,
	REDEYES_1w,  LIPS_1w,     ARM_1w,    HDLSHERO_1w, ZELDPIC_1w,  WINDOW2_1w,   HUTCH_1w,    FRANK_1w,   DRAC_1w,
	LADY_1w,     HOOD_1w,     SLIME_1w,  PEAHEAD_1w,  FOOD_1w,     PLANT_1w,     WINDOW3_1w,  TOILET_1w,  BATH_1w,
	MIRROR_1w,   WINDOW4_1w,  BROOM_1w,  UNITS_1w,    DOOR4_1w,    SHED_1w,      OILCAN_1w,   TREE2_1w,   INSHED_1w,
	DOG_1w,      CARPET_1w,   TRAP_1w,   BOLT_1w,     HERODEAD_1w, MOUSEHOLE_1w, ROCK1_1w,    ROCK2_1w,   ROCK3_1w,
	DOOR5_1w,    BAT2_1w,     BAT3_1w,   BAT4_1w,     BAT5_1w,     MUMMY_1w,     MDOOR_1w,    GOLD_1w,    ROCK4_1w,
	BOAT_1w,     ROPE_1w,     OLDMAN_1w, WHERO_1w,    GUARD_1w,    PROF_1w,      IGOR_1w,     BUNG_1w,    GDOOR_1w,
	SPACHERO_1w, FUZYHERO_1w, ARC_1w,    BOX_1w,      BUTTONS_1w,  MACHINE_1w,   TABLE_1w,    LASTOBJ_1w
};

enum objid_2w {
	/*  HERO_2w,*/ PENNY_2w = 1, SMOKE_2w,        DOOR1_2w,       DOOR5_2w,      DOOR6_2w,
	LIPS_2w,       MAID_2w,      HALLGO_2w,       PENNYLIE_2w,    PENFALL_2w,    BOOKCASE_2w,
	BOOK_2w,       KEYHOLE_2w,   BED_2w,          PANEL_2w,       CUPBOARD1_2w,  BIRD_2w,
	MATCHES_2w,    DUMB1_2w,     PHONE_2w,        BLOTPAD_2w,     DRAWER_2w,     SWITCH_2w,
	KEYHOLE2_2w,   MURDER_2w,    BALLOON_2w,      BLOCKS_2w,      PLAYPEN_2w,    WINDOW1_2w,
	WINDOW2_2w,    DUMB2_2w,     CUPBOARD2_2w,    GARLIC_2w,      KDOOR_2w,      KWINDOW_2w,
	GARDENER_2w,   REDBUTTON_2w, YELLOWBUTTON_2w, GREENBUTTON_2w, BLUEBUTTON_2w, BUTTON_2w,
	SHEDLIGHT_2w,  TOOLS_2w,     MAGNIFY_2w,      FLY1_2w,        FLY2_2w,       FLY3_2w,
	LEAF1_2w,      LEAF2_2w,     LEAF3_2w,        LEAF4_2w,       LEAF5_2w,      LEAF6_2w,
	LEAF7_2w,      LEAF8_2w,     GATELIGHT_2w,    GATES_2w,       CATNIP_2w,     BRIDGE_2w,
	ZAPPER_2w,     BUG1_2w,      BUG2_2w,         BUG3_2w,        BUG4_2w,       BUG5_2w,
	OLDMAN_2w,     WELL_2w,      SNAKE_2w,        TARDIS_2w,      GRAFFITI_2w,   STICK_2w,
	DYNAMITE_2w,   KENNEL_2w,    DOG_2w,          ROCKFALL_2w,    ROPE1_2w,      ROPE2_2w,
	OILLAMP_2w,    BANANA_2w,    HOLE_2w,         GENIE_2w,       SAFE_2w,       WILL_2w,
	MOUSEHOLE_2w,  TWINDOW_2w,   PICTURE3_2w,     WINDOW4_2w,     WINDOW5_2w,    WINDOW6_2w,
	PLANT3_2w,     CUPBOARD3_2w, PDOOR_2w,        ALBUM_2w,       CAT_2w,        PWINDOW1_2w,
	PWINDOW2_2w,   POST_2w,      DOOR4_2w,        PAPER_2w,       PENCIL_2w,     CHUTE_2w,
	BOX_2w,        DOOR2_2w,     DOOR3_2w,        DOOR7_2w,       MIRROR_2w,     HARRY_2w,
	OWINDOW_2w,    OPICTURE_2w,  OPLANT_2w,       ORGAN2_2w,      HESTER_2w,     LETTER_2w,
	BOOKCASE2_2w,  PICTURE2_2w,  PLANT2_2w,       WINDOW3_2w,     DOCTOR_2w,     ROBOT_2w,
	SCREW_2w,      DOOR8_2w,     DOOR9_2w,        DOOR10_2w,      HPICTURE_2w,   HPLANT_2w,
	COOK_2w,       COOKB_2w,     COP_2w,          HORACE_2w,      BELL_2w,       GUN_2w,
	BOTTLE_2w,     LASTOBJ_2w
};

enum objid_3w {
	/*  HERO,*/  WHERO_3w = 1, PENNY_3w,    PENNYLIE_3w,   LIPS_3w,       INPLANE_3w,  DOOR_3w,
	PLANT1_3w,   INPLANE2_3w,  WATER1_3w,   WATER2_3w,     WATER3_3w,     WATER4_3w,   WATER5_3w,
	WATER6_3w,   CLAY_3w,      NEEDLES_3w,  FLASK_3w,      BOUILLON_3w,   CHEESE_3w,   SPIDER_3w,
	PLANT3_3w,   PLANT4_3w,    BLOCK1_3w,   BLOCK2_3w,     BLOCK3_3w,     BLOCK4_3w,   VINE_3w,
	VINE1_3w,    VINE2_3w,     SWINGER_3w,  STEPS_3w,      DOCTOR_3w,     DOCLIE_3w,   CDOOR_3w,
	MOUSE_3w,    MOUSHOLE_3w,  CAGE_3w,     POST_FIRE1_3w, POST_FIRE2_3w, CAMPFIRE_3w, HUTFIRE_3w,
	POT_3w,      WINDOW_3w,    NAT1_3w,     NAT2_3w,       NAT3_3w,       NATB_3w,     NATG_3w,
	BLOWPIPE_3w, HUT_3w,       ELEPHANT_3w, E_EYES_3w,     HERO_OLD_3w,   AIRCRAFT_3w, SCROLL_3w,
	CRYSTAL_3w,  ROCK_3w,      PLANT2_3w,   GHOST_3w,      BELL_3w,       BOOK_3w,     CANDLE_3w,
	VINE3_3w,    RUSH1_3w,     RUSH2_3w,    O_EYE_3w,      FIRE_4_3w,     MOUTH_3w,    POLE_3w,
	PLANT5_3w,   LASTOBJ_3w
};

enum objid_1d {
	/*  HERO,*/  DOOR1_1d = 1, EYES1_1d,    EYES2_1d,    BAT_1d,
	PKIN_1d,     KEY_1d,       DOOR2_1d,    DOOR3_1d,    EYES3_1d,
	EYES4_1d,    CANDLE_1d,    CUPBOARD_1d, KNIFE_1d,    WHISTLE_1d,
	WARD_1d,     WDOORL_1d,    WDOORR_1d,   MASK_1d,     MONKEY_1d,
	BUTLER_1d,   CHOP_1d,      REDEYES_1d,  LIPS_1d,     ARM_1d,
	HDLSHERO_1d, DOOR4_1d,     SHED_1d,     OILCAN_1d,   DOG_1d,
	CARPET_1d,   TRAP_1d,      BOLT_1d,     HERODEAD_1d, BAT2_1d,
	BAT3_1d,     BAT4_1d,      BAT5_1d,     MUMMY_1d,    MDOOR_1d,
	GOLD_1d,     BOAT_1d,      ROPE_1d,     OLDMAN_1d,   WHERO_1d,
	GUARD_1d,    PROF_1d,      IGOR_1d,     BUNG_1d,     GDOOR_1d,
	SPACHERO_1d, FUZYHERO_1d,  ARC_1d,      LASTOBJ_1d
};

enum objid_2d {
	/*  HERO,*/      PENNY_2d = 1,   SMOKE_2d,      DOOR1_2d,     LIPS_2d,
	MAID_2d,         PENNYLIE_2d,    PENFALL_2d,    BOOKCASE_2d,  BOOK_2d,
	KEYHOLE_2d,      PANEL_2d,       CUPBOARD1_2d,  BIRD_2d,      MATCHES_2d,
	DUMB1_2d,        MURDER_2d,      BALLOON_2d,    DUMB2_2d,     CUPBOARD2_2d,
	GARLIC_2d,       KDOOR_2d,       GARDENER_2d,   BUTTON_2d,    REDBUTTON_2d,
	YELLOWBUTTON_2d, GREENBUTTON_2d, BLUEBUTTON_2d, SHEDLIGHT_2d, MAGNIFY_2d,
	FLY1_2d,         FLY2_2d,        FLY3_2d,       LEAF1_2d,     LEAF2_2d,
	LEAF3_2d,        LEAF4_2d,       LEAF5_2d,      LEAF6_2d,     LEAF7_2d,
	LEAF8_2d,        GATELIGHT_2d,   CATNIP_2d,     ZAPPER_2d,    BUG1_2d,
	BUG2_2d,         BUG3_2d,        BUG4_2d,       BUG5_2d,      OLDMAN_2d,
	WELL_2d,         SNAKE_2d,       TARDIS_2d,     STICK_2d,     DYNAMITE_2d,
	KENNEL_2d,       DOG_2d,         ROPE1_2d,      ROPE2_2d,     OILLAMP_2d,
	BANANA_2d,       GENIE_2d,       SAFE_2d,       WILL_2d,      CUPBOARD3_2d,
	PDOOR_2d,        ALBUM_2d,       CAT_2d,        DOOR4_2d,     PAPER_2d,
	PENCIL_2d,       DOOR2_2d,       DOOR3_2d,      HARRY_2d,     HESTER_2d,
	LETTER_2d,       DOCTOR_2d,      DALEK_2d,      SCREW_2d,     COOK_2d,
	COOKB_2d,        COP_2d,         HORACE_2d,     BELL_2d,      GUN_2d,
	BOTTLE_2d,       LASTOBJ_2d
};

enum objid_3d {
	/*  HERO,*/  WHERO_3d = 1, PENNY_3d,    PENNYLIE_3d,   LIPS_3d,
	INPLANE_3d,  DOOR_3d,      PLANT1_3d,   INPLANE2_3d,   WATER1_3d,
	WATER2_3d,   WATER3_3d,    WATER4_3d,   CLAY_3d,       NEEDLES_3d,
	FLASK_3d,    BOUILLON_3d,  CHEESE_3d,   SPIDER_3d,     PLANT3_3d,
	PLANT4_3d,   BLOCK1_3d,    BLOCK2_3d,   BLOCK3_3d,     VINE_3d,
	VINE2_3d,    SWINGER_3d,   DOCTOR_3d,   DOCLIE_3d,     CDOOR_3d,
	MOUSE_3d,    MOUSHOLE_3d,  CAGE_3d,     POST_FIRE1_3d, POST_FIRE2_3d,
	CAMPFIRE_3d, HUTFIRE_3d,   NAT1_3d,     NAT2_3d,       NAT3_3d,
	NATB_3d,     NATG_3d,      BLOWPIPE_3d, ELEPHANT_3d,   E_EYES_3d,
	HERO_OLD_3d, AIRCRAFT_3d,  SCROLL_3d,   CRYSTAL_3d,    ROCK_3d,
	PLANT2_3d,   GHOST_3d,     BELL_3d,     BOOK_3d,       CANDLE_3d,
	VINE3_3d,    O_EYE_3d,     FIRE_4_3d,   MOUTH_3d,      POLE_3d,
	PLANT5_3d,   LASTOBJ_3d
};

// Enumerate sequence index matching direction of travel
enum {RIGHT, LEFT, DOWN, __UP};

enum sound_t_1w {
//Hugo 1 Win
	T_TRACK1 ,    T_TRACK2,      T_TRACK3,           T_TRACK4,       T_TRACK5,
	T_TRACK6 ,    T_TRACK7,      T_TRACK8,           T_TRACK9,       T_TRACK10,
	T_TRACK11,    T_TRACK12 ,    NUM_TUNES_1w,
	// Start of sound effects
	SILENCE_1w,   TEST_SOUND_1w, DOG_BARK_1w,           BAT_FLUTTER_1w,    DOOR_CREAK_1w,
	DOOR_OPEN_1w,   MACHINE_NOISE_1w, MUNCH_1w,              BUTLER_GOTCHER_1w, FORK_BANG_1w,
	MUMMY_CHASE_1w,  MUMMY_GOTCHER_1w, SPLASH_1w
};

enum sound_t_2w {
//Hugo 2 Win
//	T_TRACK1,        T_TRACK2,        T_TRACK3,              T_TRACK4,        T_TRACK5,
//	T_TRACK6,        T_TRACK7,        T_TRACK8,              T_TRACK9,        T_TRACK10,
	/*  T_TRACK11,       T_TRACK12,*/     T_HARRY_ORGAN_2w = 12, NUM_TUNES_2w,
	// Start of sound effects
	SILENCE_2w,      TEST_SOUND_2w,   DOOR_CREAK_2w,         GET_BOOK_2w,     HORACE_SCREAM_2w,
	PANEL_UP_2w,     PANEL_DN_2w,     BALLOON_POP_2w,        DROP_MATCHES_2w, CLICK_2w,
	GATES_RUMBLE_2w, STING_2w,        HISS_2w,               BARK_2w,         GUNSHOT_2w,
	BOOM_2w,         CHASM_SCREAM_2w, GENIE_APPEAR_2w,       DING_2w,         MEOW_2w,
	SCREAM_2w,       URGH_2w,         PLANET_2w
};

enum sound_t_3w {
//Hugo 3 Win
// Music and Sound Effects
//	T_TRACK1,   T_TRACK2,      T_TRACK3,          T_TRACK4,  T_TRACK5,
//	T_TRACK6,   T_TRACK7,      T_TRACK8,          T_TRACK9,  T_TRACK10,
	/*  T_TRACK11,  T_TRACK12,*/   NUM_TUNES_3w = 12,
	// Start of sound effects
	SILENCE_3w, TEST_SOUND_3w, MAGIC_3w,          WHOOSH_3w, POINK_3w,
	ARGH_3w,    HEY_3w,        NELLIE_3w,         YODEL_3w,  SQUEAK_3w,
	BOOM_3w,    CHOMP_3w,      SCREAM_3w
};

enum sound_t_1d {
//Hugo 1 DOS
// Music and Sound Effects are not present in DOS version
	NUM_TUNES_1d = -1, SILENCE_1d = -1, TEST_SOUND_1d = -1
};

enum sound_t_2d {
//Hugo 2 DOS
// Music and Sound Effects are not present in DOS version
	NUM_TUNES_2d = -1, SILENCE_2d = -1, TEST_SOUND_2d = -1
};

enum sound_t_3d {
//Hugo 3 DOS
// Music and Sound Effects are not present in DOS version
	NUM_TUNES_3d = -1, SILENCE_3d = -1, TEST_SOUND_3d = -1
};

enum TEXTCOLORS {
	_TBLACK,    _TBLUE,         _TGREEN,       _TCYAN,
	_TRED,      _TMAGENTA,      _TBROWN,       _TWHITE,
	_TGRAY,     _TLIGHTBLUE,    _TLIGHTGREEN,  _TLIGHTCYAN,
	_TLIGHTRED, _TLIGHTMAGENTA, _TLIGHTYELLOW, _TBRIGHTWHITE
};

#endif
